from .connection import Connection as Connection
from .device import Device as Device
from .axis import Axis as Axis
from .all_axes import AllAxes as AllAxes
from .axis_settings import AxisSettings as AxisSettings
from .device_settings import DeviceSettings as DeviceSettings
from .warnings import Warnings as Warnings
from .warning_flags import WarningFlags as WarningFlags
from .unknown_response_event import UnknownResponseEvent as UnknownResponseEvent
from .device_identity import DeviceIdentity as DeviceIdentity
from .device_io import DeviceIO as DeviceIO
from .device_io_info import DeviceIOInfo as DeviceIOInfo
from .axis_identity import AxisIdentity as AxisIdentity
from .message_type import MessageType as MessageType
from .axis_type import AxisType as AxisType
from .alert_event import AlertEvent as AlertEvent
from .lockstep_axes import LockstepAxes as LockstepAxes
from .lockstep import Lockstep as Lockstep
from .oscilloscope import Oscilloscope as Oscilloscope
from .oscilloscope_data import OscilloscopeData as OscilloscopeData
from .oscilloscope_capture_properties import OscilloscopeCaptureProperties as OscilloscopeCaptureProperties
from .response import Response as Response
from .setting_constants import SettingConstants as SettingConstants
from .stream import Stream as Stream
from .stream_buffer import StreamBuffer as StreamBuffer
from .stream_mode import StreamMode as StreamMode
from .stream_axis_type import StreamAxisType as StreamAxisType
from .stream_axis_definition import StreamAxisDefinition as StreamAxisDefinition
from .transport import Transport as Transport
from .servo_tuner import ServoTuner as ServoTuner
from .servo_tuning_paramset import ServoTuningParamset as ServoTuningParamset
from .paramset_info import ParamsetInfo as ParamsetInfo
from .pid_tuning import PidTuning as PidTuning
from .servo_tuning_param import ServoTuningParam as ServoTuningParam
from .simple_tuning_param_definition import SimpleTuningParamDefinition as SimpleTuningParamDefinition
from .storage import AxisStorage as AxisStorage, DeviceStorage as DeviceStorage
from .conversion_factor import ConversionFactor as ConversionFactor
from .can_set_state_axis_response import CanSetStateAxisResponse as CanSetStateAxisResponse
from .can_set_state_device_response import CanSetStateDeviceResponse as CanSetStateDeviceResponse
from .pvt_sequence import PvtSequence as PvtSequence
from .pvt_buffer import PvtBuffer as PvtBuffer
from .pvt_mode import PvtMode as PvtMode
from .pvt_axis_type import PvtAxisType as PvtAxisType
from .pvt_axis_definition import PvtAxisDefinition as PvtAxisDefinition



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #

from typing import TYPE_CHECKING, List
from ..call import call, call_async

from ..protobufs import main_pb2

if TYPE_CHECKING:
    from .axis import Axis
    from .device import Device


class AxisStorage:
    """
    Class providing access to axis storage.
    Requires at least Firmware 7.30.
    """

    def __init__(self, axis: 'Axis'):
        self._axis = axis

    def set_string(
            self,
            key: str,
            value: str,
            encode: bool = False
    ) -> None:
        """
        Sets the axis value stored at the provided key.

        Args:
            key: Key to set the value at.
            value: Value to set.
            encode: Whether the stored value should be base64 encoded before being stored.
                This makes the string unreadable to humans using the ASCII protocol,
                however, values stored this way can be of any length and use non-ASCII and protocol reserved characters.
        """
        request = main_pb2.DeviceSetStorageRequest()
        request.interface_id = self._axis.device.connection.interface_id
        request.device = self._axis.device.device_address
        request.axis = self._axis.axis_number
        request.key = key
        request.value = value
        request.encode = encode
        call("device/set_storage", request)

    async def set_string_async(
            self,
            key: str,
            value: str,
            encode: bool = False
    ) -> None:
        """
        Sets the axis value stored at the provided key.

        Args:
            key: Key to set the value at.
            value: Value to set.
            encode: Whether the stored value should be base64 encoded before being stored.
                This makes the string unreadable to humans using the ASCII protocol,
                however, values stored this way can be of any length and use non-ASCII and protocol reserved characters.
        """
        request = main_pb2.DeviceSetStorageRequest()
        request.interface_id = self._axis.device.connection.interface_id
        request.device = self._axis.device.device_address
        request.axis = self._axis.axis_number
        request.key = key
        request.value = value
        request.encode = encode
        await call_async("device/set_storage", request)

    def get_string(
            self,
            key: str,
            decode: bool = False
    ) -> str:
        """
        Gets the axis value stored with the provided key.

        Args:
            key: Key to read the value of.
            decode: Whether the stored value should be decoded.
                Only use this when reading values set by storage.set with "encode" true.

        Returns:
            Stored value.
        """
        request = main_pb2.DeviceGetStorageRequest()
        request.interface_id = self._axis.device.connection.interface_id
        request.device = self._axis.device.device_address
        request.axis = self._axis.axis_number
        request.key = key
        request.decode = decode
        response = main_pb2.StringResponse()
        call("device/get_storage", request, response)
        return response.value

    async def get_string_async(
            self,
            key: str,
            decode: bool = False
    ) -> str:
        """
        Gets the axis value stored with the provided key.

        Args:
            key: Key to read the value of.
            decode: Whether the stored value should be decoded.
                Only use this when reading values set by storage.set with "encode" true.

        Returns:
            Stored value.
        """
        request = main_pb2.DeviceGetStorageRequest()
        request.interface_id = self._axis.device.connection.interface_id
        request.device = self._axis.device.device_address
        request.axis = self._axis.axis_number
        request.key = key
        request.decode = decode
        response = main_pb2.StringResponse()
        await call_async("device/get_storage", request, response)
        return response.value

    def set_number(
            self,
            key: str,
            value: float
    ) -> None:
        """
        Sets the value at the provided key to the provided number.

        Args:
            key: Key to set the value at.
            value: Value to set.
        """
        request = main_pb2.DeviceSetStorageNumberRequest()
        request.interface_id = self._axis.device.connection.interface_id
        request.device = self._axis.device.device_address
        request.axis = self._axis.axis_number
        request.key = key
        request.value = value
        call("device/set_storage_number", request)

    async def set_number_async(
            self,
            key: str,
            value: float
    ) -> None:
        """
        Sets the value at the provided key to the provided number.

        Args:
            key: Key to set the value at.
            value: Value to set.
        """
        request = main_pb2.DeviceSetStorageNumberRequest()
        request.interface_id = self._axis.device.connection.interface_id
        request.device = self._axis.device.device_address
        request.axis = self._axis.axis_number
        request.key = key
        request.value = value
        await call_async("device/set_storage_number", request)

    def get_number(
            self,
            key: str
    ) -> float:
        """
        Gets the value at the provided key interpreted as a number.

        Args:
            key: Key to get the value at.

        Returns:
            Stored value.
        """
        request = main_pb2.DeviceStorageRequest()
        request.interface_id = self._axis.device.connection.interface_id
        request.device = self._axis.device.device_address
        request.axis = self._axis.axis_number
        request.key = key
        response = main_pb2.DoubleResponse()
        call("device/get_storage_number", request, response)
        return response.value

    async def get_number_async(
            self,
            key: str
    ) -> float:
        """
        Gets the value at the provided key interpreted as a number.

        Args:
            key: Key to get the value at.

        Returns:
            Stored value.
        """
        request = main_pb2.DeviceStorageRequest()
        request.interface_id = self._axis.device.connection.interface_id
        request.device = self._axis.device.device_address
        request.axis = self._axis.axis_number
        request.key = key
        response = main_pb2.DoubleResponse()
        await call_async("device/get_storage_number", request, response)
        return response.value

    def set_bool(
            self,
            key: str,
            value: bool
    ) -> None:
        """
        Sets the value at the provided key to the provided boolean.

        Args:
            key: Key to set the value at.
            value: Value to set.
        """
        request = main_pb2.DeviceSetStorageBoolRequest()
        request.interface_id = self._axis.device.connection.interface_id
        request.device = self._axis.device.device_address
        request.axis = self._axis.axis_number
        request.key = key
        request.value = value
        call("device/set_storage_bool", request)

    async def set_bool_async(
            self,
            key: str,
            value: bool
    ) -> None:
        """
        Sets the value at the provided key to the provided boolean.

        Args:
            key: Key to set the value at.
            value: Value to set.
        """
        request = main_pb2.DeviceSetStorageBoolRequest()
        request.interface_id = self._axis.device.connection.interface_id
        request.device = self._axis.device.device_address
        request.axis = self._axis.axis_number
        request.key = key
        request.value = value
        await call_async("device/set_storage_bool", request)

    def get_bool(
            self,
            key: str
    ) -> bool:
        """
        Gets the value at the provided key interpreted as a boolean.

        Args:
            key: Key to get the value at.

        Returns:
            Stored value.
        """
        request = main_pb2.DeviceStorageRequest()
        request.interface_id = self._axis.device.connection.interface_id
        request.device = self._axis.device.device_address
        request.axis = self._axis.axis_number
        request.key = key
        response = main_pb2.BoolResponse()
        call("device/get_storage_bool", request, response)
        return response.value

    async def get_bool_async(
            self,
            key: str
    ) -> bool:
        """
        Gets the value at the provided key interpreted as a boolean.

        Args:
            key: Key to get the value at.

        Returns:
            Stored value.
        """
        request = main_pb2.DeviceStorageRequest()
        request.interface_id = self._axis.device.connection.interface_id
        request.device = self._axis.device.device_address
        request.axis = self._axis.axis_number
        request.key = key
        response = main_pb2.BoolResponse()
        await call_async("device/get_storage_bool", request, response)
        return response.value

    def erase_key(
            self,
            key: str
    ) -> bool:
        """
        Erases the axis value stored at the provided key.

        Args:
            key: Key to erase.

        Returns:
            A boolean indicating if the key existed.
        """
        request = main_pb2.DeviceStorageRequest()
        request.interface_id = self._axis.device.connection.interface_id
        request.device = self._axis.device.device_address
        request.axis = self._axis.axis_number
        request.key = key
        response = main_pb2.BoolResponse()
        call("device/erase_storage", request, response)
        return response.value

    async def erase_key_async(
            self,
            key: str
    ) -> bool:
        """
        Erases the axis value stored at the provided key.

        Args:
            key: Key to erase.

        Returns:
            A boolean indicating if the key existed.
        """
        request = main_pb2.DeviceStorageRequest()
        request.interface_id = self._axis.device.connection.interface_id
        request.device = self._axis.device.device_address
        request.axis = self._axis.axis_number
        request.key = key
        response = main_pb2.BoolResponse()
        await call_async("device/erase_storage", request, response)
        return response.value

    def list_keys(
            self,
            prefix: str = ""
    ) -> List[str]:
        """
        Lists the axis storage keys matching a given prefix.
        Omit the prefix to list all the keys.

        Args:
            prefix: Optional key prefix.

        Returns:
            Storage keys matching the given prefix.
        """
        request = main_pb2.DeviceStorageListKeysRequest()
        request.interface_id = self._axis.device.connection.interface_id
        request.device = self._axis.device.device_address
        request.axis = self._axis.axis_number
        request.prefix = prefix
        response = main_pb2.StringArrayResponse()
        call("device/storage_list_keys", request, response)
        return list(response.values)

    async def list_keys_async(
            self,
            prefix: str = ""
    ) -> List[str]:
        """
        Lists the axis storage keys matching a given prefix.
        Omit the prefix to list all the keys.

        Args:
            prefix: Optional key prefix.

        Returns:
            Storage keys matching the given prefix.
        """
        request = main_pb2.DeviceStorageListKeysRequest()
        request.interface_id = self._axis.device.connection.interface_id
        request.device = self._axis.device.device_address
        request.axis = self._axis.axis_number
        request.prefix = prefix
        response = main_pb2.StringArrayResponse()
        await call_async("device/storage_list_keys", request, response)
        return list(response.values)

    def key_exists(
            self,
            key: str
    ) -> bool:
        """
        Determines whether a given key exists in axis storage.

        Args:
            key: Key which existence to determine.

        Returns:
            True indicating that the key exists, false otherwise.
        """
        request = main_pb2.DeviceStorageRequest()
        request.interface_id = self._axis.device.connection.interface_id
        request.device = self._axis.device.device_address
        request.axis = self._axis.axis_number
        request.key = key
        response = main_pb2.BoolResponse()
        call("device/storage_key_exists", request, response)
        return response.value

    async def key_exists_async(
            self,
            key: str
    ) -> bool:
        """
        Determines whether a given key exists in axis storage.

        Args:
            key: Key which existence to determine.

        Returns:
            True indicating that the key exists, false otherwise.
        """
        request = main_pb2.DeviceStorageRequest()
        request.interface_id = self._axis.device.connection.interface_id
        request.device = self._axis.device.device_address
        request.axis = self._axis.axis_number
        request.key = key
        response = main_pb2.BoolResponse()
        await call_async("device/storage_key_exists", request, response)
        return response.value


class DeviceStorage:
    """
    Class providing access to device storage.
    Requires at least Firmware 7.30.
    """

    def __init__(self, device: 'Device'):
        self._device = device

    def set_string(
            self,
            key: str,
            value: str,
            encode: bool = False
    ) -> None:
        """
        Sets the device value stored at the provided key.

        Args:
            key: Key to set the value at.
            value: Value to set.
            encode: Whether the stored value should be base64 encoded before being stored.
                This makes the string unreadable to humans using the ASCII protocol,
                however, values stored this way can be of any length and use non-ASCII and protocol reserved characters.
        """
        request = main_pb2.DeviceSetStorageRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.key = key
        request.value = value
        request.encode = encode
        call("device/set_storage", request)

    async def set_string_async(
            self,
            key: str,
            value: str,
            encode: bool = False
    ) -> None:
        """
        Sets the device value stored at the provided key.

        Args:
            key: Key to set the value at.
            value: Value to set.
            encode: Whether the stored value should be base64 encoded before being stored.
                This makes the string unreadable to humans using the ASCII protocol,
                however, values stored this way can be of any length and use non-ASCII and protocol reserved characters.
        """
        request = main_pb2.DeviceSetStorageRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.key = key
        request.value = value
        request.encode = encode
        await call_async("device/set_storage", request)

    def get_string(
            self,
            key: str,
            decode: bool = False
    ) -> str:
        """
        Gets the device value stored with the provided key.

        Args:
            key: Key to read the value of.
            decode: Whether the stored value should be decoded.
                Only use this when reading values set by storage.set with "encode" true.

        Returns:
            Stored value.
        """
        request = main_pb2.DeviceGetStorageRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.key = key
        request.decode = decode
        response = main_pb2.StringResponse()
        call("device/get_storage", request, response)
        return response.value

    async def get_string_async(
            self,
            key: str,
            decode: bool = False
    ) -> str:
        """
        Gets the device value stored with the provided key.

        Args:
            key: Key to read the value of.
            decode: Whether the stored value should be decoded.
                Only use this when reading values set by storage.set with "encode" true.

        Returns:
            Stored value.
        """
        request = main_pb2.DeviceGetStorageRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.key = key
        request.decode = decode
        response = main_pb2.StringResponse()
        await call_async("device/get_storage", request, response)
        return response.value

    def set_number(
            self,
            key: str,
            value: float
    ) -> None:
        """
        Sets the value at the provided key to the provided number.

        Args:
            key: Key to set the value at.
            value: Value to set.
        """
        request = main_pb2.DeviceSetStorageNumberRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.key = key
        request.value = value
        call("device/set_storage_number", request)

    async def set_number_async(
            self,
            key: str,
            value: float
    ) -> None:
        """
        Sets the value at the provided key to the provided number.

        Args:
            key: Key to set the value at.
            value: Value to set.
        """
        request = main_pb2.DeviceSetStorageNumberRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.key = key
        request.value = value
        await call_async("device/set_storage_number", request)

    def get_number(
            self,
            key: str
    ) -> float:
        """
        Gets the value at the provided key interpreted as a number.

        Args:
            key: Key to get the value at.

        Returns:
            Stored value.
        """
        request = main_pb2.DeviceStorageRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.key = key
        response = main_pb2.DoubleResponse()
        call("device/get_storage_number", request, response)
        return response.value

    async def get_number_async(
            self,
            key: str
    ) -> float:
        """
        Gets the value at the provided key interpreted as a number.

        Args:
            key: Key to get the value at.

        Returns:
            Stored value.
        """
        request = main_pb2.DeviceStorageRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.key = key
        response = main_pb2.DoubleResponse()
        await call_async("device/get_storage_number", request, response)
        return response.value

    def set_bool(
            self,
            key: str,
            value: bool
    ) -> None:
        """
        Sets the value at the provided key to the provided boolean.

        Args:
            key: Key to set the value at.
            value: Value to set.
        """
        request = main_pb2.DeviceSetStorageBoolRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.key = key
        request.value = value
        call("device/set_storage_bool", request)

    async def set_bool_async(
            self,
            key: str,
            value: bool
    ) -> None:
        """
        Sets the value at the provided key to the provided boolean.

        Args:
            key: Key to set the value at.
            value: Value to set.
        """
        request = main_pb2.DeviceSetStorageBoolRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.key = key
        request.value = value
        await call_async("device/set_storage_bool", request)

    def get_bool(
            self,
            key: str
    ) -> bool:
        """
        Gets the value at the provided key interpreted as a boolean.

        Args:
            key: Key to get the value at.

        Returns:
            Stored value.
        """
        request = main_pb2.DeviceStorageRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.key = key
        response = main_pb2.BoolResponse()
        call("device/get_storage_bool", request, response)
        return response.value

    async def get_bool_async(
            self,
            key: str
    ) -> bool:
        """
        Gets the value at the provided key interpreted as a boolean.

        Args:
            key: Key to get the value at.

        Returns:
            Stored value.
        """
        request = main_pb2.DeviceStorageRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.key = key
        response = main_pb2.BoolResponse()
        await call_async("device/get_storage_bool", request, response)
        return response.value

    def erase_key(
            self,
            key: str
    ) -> bool:
        """
        Erases the device value stored at the provided key.

        Args:
            key: Key to erase.

        Returns:
            A boolean indicating if the key existed.
        """
        request = main_pb2.DeviceStorageRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.key = key
        response = main_pb2.BoolResponse()
        call("device/erase_storage", request, response)
        return response.value

    async def erase_key_async(
            self,
            key: str
    ) -> bool:
        """
        Erases the device value stored at the provided key.

        Args:
            key: Key to erase.

        Returns:
            A boolean indicating if the key existed.
        """
        request = main_pb2.DeviceStorageRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.key = key
        response = main_pb2.BoolResponse()
        await call_async("device/erase_storage", request, response)
        return response.value

    def list_keys(
            self,
            prefix: str = ""
    ) -> List[str]:
        """
        Lists the device storage keys matching a given prefix.
        Omit the prefix to list all the keys.

        Args:
            prefix: Optional key prefix.

        Returns:
            Storage keys matching the given prefix.
        """
        request = main_pb2.DeviceStorageListKeysRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.prefix = prefix
        response = main_pb2.StringArrayResponse()
        call("device/storage_list_keys", request, response)
        return list(response.values)

    async def list_keys_async(
            self,
            prefix: str = ""
    ) -> List[str]:
        """
        Lists the device storage keys matching a given prefix.
        Omit the prefix to list all the keys.

        Args:
            prefix: Optional key prefix.

        Returns:
            Storage keys matching the given prefix.
        """
        request = main_pb2.DeviceStorageListKeysRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.prefix = prefix
        response = main_pb2.StringArrayResponse()
        await call_async("device/storage_list_keys", request, response)
        return list(response.values)

    def key_exists(
            self,
            key: str
    ) -> bool:
        """
        Determines whether a given key exists in device storage.

        Args:
            key: Key which existence to determine.

        Returns:
            True indicating that the key exists, false otherwise.
        """
        request = main_pb2.DeviceStorageRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.key = key
        response = main_pb2.BoolResponse()
        call("device/storage_key_exists", request, response)
        return response.value

    async def key_exists_async(
            self,
            key: str
    ) -> bool:
        """
        Determines whether a given key exists in device storage.

        Args:
            key: Key which existence to determine.

        Returns:
            True indicating that the key exists, false otherwise.
        """
        request = main_pb2.DeviceStorageRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.key = key
        response = main_pb2.BoolResponse()
        await call_async("device/storage_key_exists", request, response)
        return response.value



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
# pylint: disable=W0201

from typing import List, Optional  # pylint: disable=unused-import
from ..protobufs import main_pb2
from .axis_mapping import AxisMapping
from .axis_transformation import AxisTransformation


class TranslatorConfig:
    """
    Configuration of a translator.
    """

    def __init__(
            self: 'TranslatorConfig',
            axis_mappings: Optional[List[AxisMapping]] = None,
            axis_transformations: Optional[List[AxisTransformation]] = None
    ) -> None:
        self._axis_mappings = axis_mappings
        self._axis_transformations = axis_transformations

    @property
    def axis_mappings(self) -> Optional[List[AxisMapping]]:
        """
        Optional custom mapping of translator axes to stream axes.
        """

        return self._axis_mappings

    @axis_mappings.setter
    def axis_mappings(self, value: Optional[List[AxisMapping]]) -> None:
        self._axis_mappings = value

    @property
    def axis_transformations(self) -> Optional[List[AxisTransformation]]:
        """
        Optional transformation of axes.
        """

        return self._axis_transformations

    @axis_transformations.setter
    def axis_transformations(self, value: Optional[List[AxisTransformation]]) -> None:
        self._axis_transformations = value

    def __repr__(self) -> str:
        return str(self.__dict__)

    @staticmethod
    def to_protobuf(source: 'Optional[TranslatorConfig]') -> main_pb2.TranslatorConfig:
        if source is None:
            return main_pb2.TranslatorConfig()

        if not isinstance(source, TranslatorConfig):
            raise TypeError("Provided value is not TranslatorConfig.")

        pb_data = main_pb2.TranslatorConfig()
        if source.axis_mappings is not None:
            pb_data.axis_mappings.extend(
                [AxisMapping.to_protobuf(item) for item in source.axis_mappings])
        if source.axis_transformations is not None:
            pb_data.axis_transformations.extend(
                [AxisTransformation.to_protobuf(item) for item in source.axis_transformations])
        return pb_data



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobufs/main.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14protobufs/main.proto\x12\x16zaber.motion.protobufs\"\x1a\n\x07Request\x12\x0f\n\x07request\x18\x01 \x01(\t\"\xb9\x01\n\x08Response\x12?\n\x08response\x18\x01 \x01(\x0e\x32-.zaber.motion.protobufs.Response.ResponseType\x12\x32\n\nerror_type\x18\x02 \x01(\x0e\x32\x1e.zaber.motion.protobufs.Errors\x12\x15\n\rerror_message\x18\x03 \x01(\t\"!\n\x0cResponseType\x12\x06\n\x02OK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\"\x16\n\x05\x45vent\x12\r\n\x05\x65vent\x18\x01 \x01(\t\"\x0e\n\x0c\x45mptyRequest\"\x1d\n\x0c\x42oolResponse\x12\r\n\x05value\x18\x01 \x01(\x08\"\x1f\n\x0e\x44oubleResponse\x12\r\n\x05value\x18\x01 \x01(\x01\"%\n\x13\x44oubleArrayResponse\x12\x0e\n\x06values\x18\x01 \x03(\x01\"\x1c\n\x0bIntResponse\x12\r\n\x05value\x18\x01 \x01(\x05\"\x1f\n\x0eStringResponse\x12\r\n\x05value\x18\x01 \x01(\t\"%\n\x13StringArrayResponse\x12\x0e\n\x06values\x18\x01 \x03(\t\"\xdd\x01\n\x0c\x41xisIdentity\x12\x15\n\ris_peripheral\x18\x01 \x01(\x08\x12\x15\n\rperipheral_id\x18\x02 \x01(\x05\x12\x17\n\x0fperipheral_name\x18\x03 \x01(\t\x12@\n\taxis_type\x18\x04 \x01(\x0e\x32-.zaber.motion.protobufs.AxisIdentity.AxisType\x12\x13\n\x0bis_modified\x18\x05 \x01(\x08\"/\n\x08\x41xisType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06LINEAR\x10\x01\x12\n\n\x06ROTARY\x10\x02\"\xcb\x01\n\x0e\x44\x65viceIdentity\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x15\n\rserial_number\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\naxis_count\x18\x04 \x01(\x05\x12\x41\n\x10\x66irmware_version\x18\x05 \x01(\x0b\x32\'.zaber.motion.protobufs.FirmwareVersion\x12\x13\n\x0bis_modified\x18\x06 \x01(\x08\x12\x15\n\ris_integrated\x18\x07 \x01(\x08\">\n\x0f\x46irmwareVersion\x12\r\n\x05major\x18\x01 \x01(\x05\x12\r\n\x05minor\x18\x02 \x01(\x05\x12\r\n\x05\x62uild\x18\x03 \x01(\x05\"\x8a\x01\n\x0c\x44\x65viceIOInfo\x12\x1d\n\x15number_analog_outputs\x18\x02 \x01(\x05\x12\x1c\n\x14number_analog_inputs\x18\x03 \x01(\x05\x12\x1e\n\x16number_digital_outputs\x18\x04 \x01(\x05\x12\x1d\n\x15number_digital_inputs\x18\x05 \x01(\x05\"*\n\x0bMeasurement\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x0c\n\x04unit\x18\x07 \x01(\t\">\n\x14StreamAxisDefinition\x12\x13\n\x0b\x61xis_number\x18\x01 \x01(\x05\x12\x11\n\taxis_type\x18\x02 \x01(\x05\"<\n\x1aInvalidPacketExceptionData\x12\x0e\n\x06packet\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\">\n\"DeviceAddressConflictExceptionData\x12\x18\n\x10\x64\x65vice_addresses\x18\x01 \x03(\x05\"b\n MovementInterruptedExceptionData\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x03 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x04 \x01(\x05\"J\n&StreamMovementInterruptedExceptionData\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"G\n#PvtMovementInterruptedExceptionData\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"]\n\x1bMovementFailedExceptionData\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x03 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x04 \x01(\x05\"E\n!StreamMovementFailedExceptionData\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"B\n\x1ePvtMovementFailedExceptionData\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"B\n\x1cStreamExecutionExceptionData\x12\x12\n\nerror_flag\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\x80\x01\n\x19PvtExecutionExceptionData\x12\x12\n\nerror_flag\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12?\n\x0einvalid_points\x18\x03 \x03(\x0b\x32\'.zaber.motion.protobufs.InvalidPvtPoint\"/\n\x0fInvalidPvtPoint\x12\r\n\x05index\x18\x01 \x01(\x05\x12\r\n\x05point\x18\x02 \x01(\t\"0\n\x1cInvalidResponseExceptionData\x12\x10\n\x08response\x18\x01 \x01(\t\"\xb7\x01\n\x1a\x43ommandFailedExceptionData\x12\x15\n\rresponse_data\x18\x01 \x01(\t\x12\x12\n\nreply_flag\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x04 \x01(\t\x12\x16\n\x0e\x64\x65vice_address\x18\x05 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x06 \x01(\x05\x12\n\n\x02id\x18\x07 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x08 \x01(\t\"9\n BinaryCommandFailedExceptionData\x12\x15\n\rresponse_data\x18\x01 \x01(\x05\"\x89\x01\n\x1fSetPeripheralStateExceptionData\x12\x13\n\x0b\x61xis_number\x18\x01 \x01(\x05\x12\x10\n\x08settings\x18\x02 \x03(\t\x12\x14\n\x0cservo_tuning\x18\x03 \x01(\t\x12\x0f\n\x07storage\x18\x04 \x03(\t\x12\x18\n\x10stored_positions\x18\x05 \x03(\t\"\xfd\x01\n\x1bSetDeviceStateExceptionData\x12L\n\x0bperipherals\x18\x02 \x03(\x0b\x32\x37.zaber.motion.protobufs.SetPeripheralStateExceptionData\x12\x10\n\x08settings\x18\x03 \x03(\t\x12\x16\n\x0estream_buffers\x18\x04 \x03(\t\x12\x10\n\x08triggers\x18\x05 \x03(\t\x12\x14\n\x0cservo_tuning\x18\x06 \x01(\t\x12\x0f\n\x07storage\x18\x07 \x03(\t\x12\x18\n\x10stored_positions\x18\x08 \x03(\t\x12\x13\n\x0bpvt_buffers\x18\t \x03(\t\"g\n\x1b\x43ommandTooLongExceptionData\x12\x0b\n\x03\x66it\x18\x01 \x01(\t\x12\x11\n\tremainder\x18\x02 \x01(\t\x12\x13\n\x0bpacket_size\x18\x03 \x01(\x05\x12\x13\n\x0bpackets_max\x18\x04 \x01(\x05\"V\n\x0bTestRequest\x12\x14\n\x0creturn_error\x18\x01 \x01(\x08\x12\x11\n\tdata_ping\x18\x02 \x01(\t\x12\x1e\n\x16return_error_with_data\x18\x03 \x01(\x08\"!\n\x0cTestResponse\x12\x11\n\tdata_pong\x18\x01 \x01(\t\"%\n\x10TestResponseLong\x12\x11\n\tdata_pong\x18\x01 \x03(\t\"\x19\n\tTestEvent\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"-\n\x1cToolsListSerialPortsResponse\x12\r\n\x05ports\x18\x01 \x03(\t\"&\n\x16SetInternalModeRequest\x12\x0c\n\x04mode\x18\x01 \x01(\x08\"I\n\x18SetDeviceDbSourceRequest\x12\x13\n\x0bsource_type\x18\x01 \x01(\x05\x12\x18\n\x10url_or_file_path\x18\x02 \x01(\t\"G\n\x1aToggleDeviceDbStoreRequest\x12\x11\n\ttoggle_on\x18\x01 \x01(\x08\x12\x16\n\x0estore_location\x18\x02 \x01(\t\"+\n\x1b\x44\x65viceDbFailedExceptionData\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"\xa7\x02\n\x14OpenInterfaceRequest\x12=\n\x0einterface_type\x18\x01 \x01(\x0e\x32%.zaber.motion.protobufs.InterfaceType\x12\x11\n\tport_name\x18\x02 \x01(\t\x12\x11\n\tbaud_rate\x18\x03 \x01(\x05\x12\x11\n\thost_name\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x05\x12\x11\n\ttransport\x18\x06 \x01(\x05\x12 \n\x18reject_routed_connection\x18\x07 \x01(\x08\x12\x10\n\x08\x63loud_id\x18\x08 \x01(\t\x12\x17\n\x0f\x63onnection_name\x18\t \x01(\t\x12\r\n\x05realm\x18\n \x01(\t\x12\r\n\x05token\x18\x0b \x01(\t\x12\x0b\n\x03\x61pi\x18\x0c \x01(\t\"-\n\x15OpenInterfaceResponse\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\"-\n\x15InterfaceEmptyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\"C\n\x1aSetInterfaceTimeoutRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0f\n\x07timeout\x18\x02 \x01(\x05\"N\n\"SetInterfaceChecksumEnabledRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x12\n\nis_enabled\x18\x02 \x01(\x08\"F\n\x10\x41xisEmptyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"\x83\x01\n\x15GenericCommandRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\x12\x14\n\x0c\x63heck_errors\x18\x05 \x01(\x08\x12\x0f\n\x07timeout\x18\x06 \x01(\x05\"\xc8\x01\n\x16GenericCommandResponse\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x03 \x01(\x05\x12\x12\n\nreply_flag\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x07 \x01(\t\x12\x39\n\x0cmessage_type\x18\x08 \x01(\x0e\x32#.zaber.motion.protobufs.MessageType\"e\n GenericCommandResponseCollection\x12\x41\n\tresponses\x18\x02 \x03(\x0b\x32..zaber.motion.protobufs.GenericCommandResponse\"\xdc\x01\n\x14UnknownResponseEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x03 \x01(\x05\x12\x12\n\nreply_flag\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x07 \x01(\t\x12\x39\n\x0cmessage_type\x18\x08 \x01(\x0e\x32#.zaber.motion.protobufs.MessageType\"\x83\x01\n\nAlertEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x03 \x01(\x05\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\"t\n\x11\x44isconnectedEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x32\n\nerror_type\x18\x02 \x01(\x0e\x32\x1e.zaber.motion.protobufs.Errors\x12\x15\n\rerror_message\x18\x03 \x01(\t\"~\n\x15\x44\x65viceIdentifyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12?\n\x0e\x61ssume_version\x18\x03 \x01(\x0b\x32\'.zaber.motion.protobufs.FirmwareVersion\"D\n\x15\x44\x65viceRenumberRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x15\n\rfirst_address\x18\x02 \x01(\x05\"E\n\x13\x44\x65viceDetectRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x18\n\x10identify_devices\x18\x02 \x01(\x08\"\'\n\x14\x44\x65viceDetectResponse\x12\x0f\n\x07\x64\x65vices\x18\x01 \x03(\x05\"`\n\x11\x44\x65viceHomeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"n\n\x1a\x44\x65viceWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x1c\n\x14throw_error_on_fault\x18\x04 \x01(\x08\"\xd0\x02\n\x11\x44\x65viceMoveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\x12@\n\x04type\x18\x05 \x01(\x0e\x32\x32.zaber.motion.protobufs.DeviceMoveRequest.MoveType\x12\x0b\n\x03\x61rg\x18\x06 \x01(\x01\x12\x0c\n\x04unit\x18\x07 \x01(\t\x12\x10\n\x08velocity\x18\x08 \x01(\x01\x12\x15\n\rvelocity_unit\x18\t \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\n \x01(\x01\x12\x19\n\x11\x61\x63\x63\x65leration_unit\x18\x0b \x01(\t\"7\n\x08MoveType\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\x12\x07\n\x03VEL\x10\x02\x12\x07\n\x03MAX\x10\x03\x12\x07\n\x03MIN\x10\x04\"`\n\x11\x44\x65viceStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"C\n\x12\x44\x65viceOnAllRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x02 \x01(\x08\"/\n\x13\x44\x65viceOnAllResponse\x12\x18\n\x10\x64\x65vice_addresses\x18\x01 \x03(\x05\"]\n\x18\x44\x65viceGetWarningsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\r\n\x05\x63lear\x18\x04 \x01(\x08\"*\n\x19\x44\x65viceGetWarningsResponse\x12\r\n\x05\x66lags\x18\x01 \x03(\t\"x\n\x1aWaitToClearWarningsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\x12\x15\n\rwarning_flags\x18\x05 \x03(\t\"Z\n\x1c\x44\x65viceGetAllDigitalIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\"/\n\x1d\x44\x65viceGetAllDigitalIOResponse\x12\x0e\n\x06values\x18\x01 \x03(\x08\"Y\n\x1b\x44\x65viceGetAllAnalogIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\".\n\x1c\x44\x65viceGetAllAnalogIOResponse\x12\x0e\n\x06values\x18\x01 \x03(\x01\"o\n\x19\x44\x65viceGetDigitalIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\"n\n\x18\x44\x65viceGetAnalogIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\"Y\n!DeviceSetAllDigitalOutputsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0e\n\x06values\x18\x03 \x03(\x08\"X\n DeviceSetAllAnalogOutputsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0e\n\x06values\x18\x03 \x03(\x01\"l\n\x1d\x44\x65viceSetDigitalOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x03 \x01(\x05\x12\r\n\x05value\x18\x04 \x01(\x08\"k\n\x1c\x44\x65viceSetAnalogOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x03 \x01(\x05\x12\r\n\x05value\x18\x04 \x01(\x01\"6\n\x13SetLogOutputRequest\x12\x0c\n\x04mode\x18\x01 \x01(\x05\x12\x11\n\tfile_path\x18\x02 \x01(\t\"l\n\x17\x44\x65viceGetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\x0c\n\x04unit\x18\x05 \x01(\t\"\x94\x01\n\x1b\x44\x65viceConvertSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\x0c\n\x04unit\x18\x05 \x01(\t\x12\r\n\x05value\x18\x06 \x01(\x01\x12\x13\n\x0b\x66rom_native\x18\x07 \x01(\x08\"{\n\x17\x44\x65viceSetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\x01\x12\x0c\n\x04unit\x18\x06 \x01(\t\"p\n\x1a\x44\x65viceSetSettingStrRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\"\x9e\x01\n\x15PrepareCommandRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x18\n\x10\x63ommand_template\x18\x04 \x01(\t\x12\x37\n\nparameters\x18\x05 \x03(\x0b\x32#.zaber.motion.protobufs.Measurement\"M\n\x14WaitToRespondRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\"f\n\x15LockstepEnableRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x0c\n\x04\x61xes\x18\x04 \x03(\x05\"r\n\x16LockstepDisableRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"o\n\x13LockstepStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"o\n\x13LockstepHomeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"\xe1\x02\n\x13LockstepMoveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\x12\x42\n\x04type\x18\x05 \x01(\x0e\x32\x34.zaber.motion.protobufs.LockstepMoveRequest.MoveType\x12\x0b\n\x03\x61rg\x18\x06 \x01(\x01\x12\x0c\n\x04unit\x18\x08 \x01(\t\x12\x10\n\x08velocity\x18\t \x01(\x01\x12\x15\n\rvelocity_unit\x18\n \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x0b \x01(\x01\x12\x19\n\x11\x61\x63\x63\x65leration_unit\x18\x0c \x01(\t\"7\n\x08MoveType\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\x12\x07\n\x03VEL\x10\x02\x12\x07\n\x03MAX\x10\x03\x12\x07\n\x03MIN\x10\x04\"}\n\x1cLockstepWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x1c\n\x14throw_error_on_fault\x18\x04 \x01(\x08\"W\n\x14LockstepEmptyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\"N\n\x0cLockstepAxes\x12\x0e\n\x06\x61xis_1\x18\x01 \x01(\x05\x12\x0e\n\x06\x61xis_2\x18\x02 \x01(\x05\x12\x0e\n\x06\x61xis_3\x18\x03 \x01(\x05\x12\x0e\n\x06\x61xis_4\x18\x04 \x01(\x05\".\n\x1eLockstepGetAxisNumbersResponse\x12\x0c\n\x04\x61xes\x18\x01 \x03(\x05\"c\n\x12LockstepGetRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"\x86\x01\n\x12LockstepSetRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\r\n\x05value\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\x12\x12\n\naxis_index\x18\x06 \x01(\x05\"d\n\x1dOscilloscopeAddChannelRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\"k\n\x1cOscilloscopeStartStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\r\n\x05start\x18\x03 \x01(\x08\x12\x16\n\x0e\x63\x61pture_length\x18\x04 \x01(\x05\",\n\x18OscilloscopeReadResponse\x12\x10\n\x08\x64\x61ta_ids\x18\x01 \x03(\x05\"-\n\x1aOscilloscopeDataIdentifier\x12\x0f\n\x07\x64\x61ta_id\x18\x01 \x01(\x05\"E\n\x1dOscilloscopeCaptureProperties\x12\x0f\n\x07setting\x18\x01 \x01(\t\x12\x13\n\x0b\x61xis_number\x18\x02 \x01(\x05\";\n\x1aOscilloscopeDataGetRequest\x12\x0f\n\x07\x64\x61ta_id\x18\x01 \x01(\x05\x12\x0c\n\x04unit\x18\x02 \x01(\t\"T\n$OscilloscopeDataGetSampleTimeRequest\x12\x0f\n\x07\x64\x61ta_id\x18\x01 \x01(\x05\x12\x0c\n\x04unit\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\"2\n\"OscilloscopeDataGetSamplesResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x01\"l\n\x16StreamSetupLiveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\x0c\n\x04\x61xes\x18\x05 \x03(\x05\"\xa3\x01\n\x1fStreamSetupLiveCompositeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12:\n\x04\x61xes\x18\x05 \x03(\x0b\x32,.zaber.motion.protobufs.StreamAxisDefinition\"\x98\x01\n\x17StreamSetupStoreRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\x15\n\rstream_buffer\x18\x05 \x01(\x05\x12\x12\n\npvt_buffer\x18\x06 \x01(\x05\x12\x0c\n\x04\x61xes\x18\x07 \x03(\x05\"\xcf\x01\n StreamSetupStoreCompositeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\x15\n\rstream_buffer\x18\x05 \x01(\x05\x12\x12\n\npvt_buffer\x18\x06 \x01(\x05\x12:\n\x04\x61xes\x18\x07 \x03(\x0b\x32,.zaber.motion.protobufs.StreamAxisDefinition\"\xab\x01\n$StreamSetupStoreArbitraryAxesRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\x15\n\rstream_buffer\x18\x05 \x01(\x05\x12\x12\n\npvt_buffer\x18\x06 \x01(\x05\x12\x12\n\naxes_count\x18\x07 \x01(\x05\"\x84\x01\n\x11StreamCallRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\x15\n\rstream_buffer\x18\x05 \x01(\x05\x12\x12\n\npvt_buffer\x18\x06 \x01(\x05\"\xd1\x02\n\x0fPvtPointRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12:\n\x04type\x18\x05 \x01(\x0e\x32,.zaber.motion.protobufs.PvtPointRequest.Type\x12\x36\n\tpositions\x18\x06 \x03(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x37\n\nvelocities\x18\x07 \x03(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x31\n\x04time\x18\x08 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\"\x18\n\x04Type\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\"\x85\x02\n\x11StreamLineRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12<\n\x04type\x18\x05 \x01(\x0e\x32..zaber.motion.protobufs.StreamLineRequest.Type\x12\x35\n\x08\x65ndpoint\x18\x06 \x03(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x1b\n\x13target_axes_indices\x18\x07 \x03(\x05\"\x18\n\x04Type\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\"\xbe\x03\n\x10StreamArcRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12;\n\x04type\x18\x05 \x01(\x0e\x32-.zaber.motion.protobufs.StreamArcRequest.Type\x12\x1a\n\x12rotation_direction\x18\x06 \x01(\x05\x12\x35\n\x08\x63\x65nter_x\x18\x07 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x35\n\x08\x63\x65nter_y\x18\x08 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x32\n\x05\x65nd_x\x18\t \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x32\n\x05\x65nd_y\x18\n \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x1b\n\x13target_axes_indices\x18\x0b \x03(\x05\"\x18\n\x04Type\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\"\xdc\x02\n\x13StreamCircleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12>\n\x04type\x18\x05 \x01(\x0e\x32\x30.zaber.motion.protobufs.StreamCircleRequest.Type\x12\x1a\n\x12rotation_direction\x18\x06 \x01(\x05\x12\x35\n\x08\x63\x65nter_x\x18\x07 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x35\n\x08\x63\x65nter_y\x18\x08 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x1b\n\x13target_axes_indices\x18\t \x03(\x05\"\x18\n\x04Type\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\"\x8c\x01\n\x1dStreamWaitDigitalInputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\x16\n\x0e\x63hannel_number\x18\x05 \x01(\x05\x12\r\n\x05value\x18\x06 \x01(\x08\"\x9e\x01\n\x1cStreamWaitAnalogInputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\x16\n\x0e\x63hannel_number\x18\x05 \x01(\x05\x12\x11\n\tcondition\x18\x06 \x01(\t\x12\r\n\x05value\x18\x07 \x01(\x01\"\x8c\x01\n\x1dStreamSetDigitalOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\x16\n\x0e\x63hannel_number\x18\x05 \x01(\x05\x12\r\n\x05value\x18\x06 \x01(\x08\"\x8b\x01\n\x1cStreamSetAnalogOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\x16\n\x0e\x63hannel_number\x18\x05 \x01(\x05\x12\r\n\x05value\x18\x06 \x01(\x01\"\x80\x01\n StreamToggleDigitalOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\x16\n\x0e\x63hannel_number\x18\x05 \x01(\x05\"y\n!StreamSetAllDigitalOutputsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\x0e\n\x06values\x18\x05 \x03(\x08\"x\n StreamSetAllAnalogOutputsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\x0e\n\x06values\x18\x05 \x03(\x01\"u\n\x11StreamWaitRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\x0c\n\x04time\x18\x05 \x01(\x01\x12\x0c\n\x04unit\x18\x06 \x01(\t\"\x80\x01\n\x1aStreamWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\x1c\n\x14throw_error_on_fault\x18\x05 \x01(\x08\"Z\n\x12StreamEmptyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\"S\n\x15StreamGetAxesResponse\x12:\n\x04\x61xes\x18\x01 \x03(\x0b\x32,.zaber.motion.protobufs.StreamAxisDefinition\"n\n\x18StreamGetMaxSpeedRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\x0c\n\x04unit\x18\x05 \x01(\t\"\x81\x01\n\x18StreamSetMaxSpeedRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x05 \x01(\x08\x12\x11\n\tmax_speed\x18\x06 \x01(\x01\x12\x0c\n\x04unit\x18\x07 \x01(\t\"\x7f\n)StreamGetMaxTangentialAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\x0c\n\x04unit\x18\x05 \x01(\t\"\xa4\x01\n)StreamSetMaxTangentialAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12#\n\x1bmax_tangential_acceleration\x18\x05 \x01(\x01\x12\x0c\n\x04unit\x18\x06 \x01(\t\"\x80\x01\n*StreamGetMaxCentripetalAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\x0c\n\x04unit\x18\x05 \x01(\t\"\xa6\x01\n*StreamSetMaxCentripetalAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12$\n\x1cmax_centripetal_acceleration\x18\x05 \x01(\x01\x12\x0c\n\x04unit\x18\x06 \x01(\t\"e\n\x1dStreamBufferGetContentRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tbuffer_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\"6\n\x1eStreamBufferGetContentResponse\x12\x14\n\x0c\x62uffer_lines\x18\x01 \x03(\t\"`\n\x18StreamBufferEraseRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tbuffer_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\"t\n\x1bStreamGenericCommandRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\x0f\n\x07\x63ommand\x18\x05 \x01(\t\"w\n StreamGenericCommandBatchRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0b\n\x03pvt\x18\x04 \x01(\x08\x12\r\n\x05\x62\x61tch\x18\x05 \x03(\t\"c\n\x14\x42inaryReplyOnlyEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x05\"\xbb\x01\n\x1aOpenBinaryInterfaceRequest\x12=\n\x0einterface_type\x18\x01 \x01(\x0e\x32%.zaber.motion.protobufs.InterfaceType\x12\x11\n\tport_name\x18\x02 \x01(\t\x12\x11\n\tbaud_rate\x18\x03 \x01(\x05\x12\x11\n\thost_name\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x05\x12\x17\n\x0fuse_message_ids\x18\x06 \x01(\x08\"i\n\x1aUnknownBinaryResponseEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x05\"\x82\x01\n\x14GenericBinaryRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x05\x12\x14\n\x0c\x63heck_errors\x18\x05 \x01(\x08\x12\x0f\n\x07timeout\x18\x06 \x01(\x01\"F\n\rBinaryMessage\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x05\"R\n\x17\x42inaryMessageCollection\x12\x37\n\x08messages\x18\x02 \x03(\x0b\x32%.zaber.motion.protobufs.BinaryMessage\":\n\x12\x44\x65viceEmptyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"\xd9\x02\n\x14\x42inaryDeviceIdentity\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x15\n\rserial_number\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x41\n\x10\x66irmware_version\x18\x05 \x01(\x0b\x32\'.zaber.motion.protobufs.FirmwareVersion\x12\x15\n\ris_peripheral\x18\x06 \x01(\x08\x12\x15\n\rperipheral_id\x18\x07 \x01(\x05\x12\x17\n\x0fperipheral_name\x18\x08 \x01(\t\x12L\n\x0b\x64\x65vice_type\x18\t \x01(\x0e\x32\x37.zaber.motion.protobufs.BinaryDeviceIdentity.DeviceType\"1\n\nDeviceType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06LINEAR\x10\x01\x12\n\n\x06ROTARY\x10\x02\"\x99\x01\n\x1d\x42inaryGenericWithUnitsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x01\x12\x11\n\tfrom_unit\x18\x05 \x01(\t\x12\x0f\n\x07to_unit\x18\x06 \x01(\t\x12\x0f\n\x07timeout\x18\x07 \x01(\x01\"^\n\x17\x42inaryDeviceHomeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x0c\n\x04unit\x18\x04 \x01(\t\"\xda\x01\n\x17\x42inaryDeviceMoveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x46\n\x04type\x18\x04 \x01(\x0e\x32\x38.zaber.motion.protobufs.BinaryDeviceMoveRequest.MoveType\x12\x0b\n\x03\x61rg\x18\x05 \x01(\x01\x12\x0c\n\x04unit\x18\x06 \x01(\t\"%\n\x08MoveType\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\x12\x07\n\x03VEL\x10\x02\"^\n\x17\x42inaryDeviceStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x0c\n\x04unit\x18\x04 \x01(\t\"K\n\x19\x42inaryDeviceDetectRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x18\n\x10identify_devices\x18\x02 \x01(\x08\"-\n\x1a\x42inaryDeviceDetectResponse\x12\x0f\n\x07\x64\x65vices\x18\x01 \x03(\x05\"d\n\x1d\x42inaryDeviceGetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07setting\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"s\n\x1d\x42inaryDeviceSetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07setting\x18\x03 \x01(\x05\x12\r\n\x05value\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"2\n\x1a\x43ustomInterfaceReadRequest\x12\x14\n\x0ctransport_id\x18\x01 \x01(\x05\"D\n\x1b\x43ustomInterfaceWriteRequest\x12\x14\n\x0ctransport_id\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"3\n\x1b\x43ustomInterfaceOpenResponse\x12\x14\n\x0ctransport_id\x18\x01 \x01(\x05\"J\n\x1b\x43ustomInterfaceCloseRequest\x12\x14\n\x0ctransport_id\x18\x01 \x01(\x05\x12\x15\n\rerror_message\x18\x02 \x01(\t\"W\n\x12\x43\x61nSetStateRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\r\n\x05state\x18\x04 \x01(\t\"=\n\x17\x43\x61nSetStateAxisResponse\x12\x13\n\x0b\x61xis_number\x18\x01 \x01(\x05\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"p\n\x19\x43\x61nSetStateDeviceResponse\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12\x44\n\x0b\x61xis_errors\x18\x02 \x03(\x0b\x32/.zaber.motion.protobufs.CanSetStateAxisResponse\"i\n\x0fSetStateRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\r\n\x05state\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65vice_only\x18\x05 \x01(\x08\"Z\n\x12ServoTuningRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x10\n\x08paramset\x18\x04 \x01(\x05\"/\n\x10ServoTuningParam\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\"g\n\x0cParamsetInfo\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x38\n\x06params\x18\x02 \x03(\x0b\x32(.zaber.motion.protobufs.ServoTuningParam\"\x9e\x01\n\x15SetServoTuningRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x10\n\x08paramset\x18\x04 \x01(\x05\x12?\n\rtuning_params\x18\x05 \x03(\x0b\x32(.zaber.motion.protobufs.ServoTuningParam\"n\n\x0cLoadParamset\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x13\n\x0bto_paramset\x18\x04 \x01(\x05\x12\x15\n\rfrom_paramset\x18\x05 \x01(\x05\"\x8d\x01\n\x18SetServoTuningPIDRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x10\n\x08paramset\x18\x04 \x01(\x05\x12\t\n\x01p\x18\x05 \x01(\x01\x12\t\n\x01i\x18\x06 \x01(\x01\x12\t\n\x01\x64\x18\x07 \x01(\x01\x12\n\n\x02\x66\x63\x18\x08 \x01(\x01\"W\n\tPidTuning\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\t\n\x01p\x18\x03 \x01(\x01\x12\t\n\x01i\x18\x04 \x01(\x01\x12\t\n\x01\x64\x18\x05 \x01(\x01\x12\n\n\x02\x66\x63\x18\x06 \x01(\x01\"\xc2\x01\n\x0fSetSimpleTuning\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x10\n\x08paramset\x18\x04 \x01(\x05\x12\x15\n\rcarriage_mass\x18\x05 \x01(\x01\x12\x11\n\tload_mass\x18\x06 \x01(\x01\x12?\n\rtuning_params\x18\x07 \x03(\x0b\x32(.zaber.motion.protobufs.ServoTuningParam\"d\n\x1bSimpleTuningParamDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tmin_label\x18\x02 \x01(\t\x12\x11\n\tmax_label\x18\x03 \x01(\t\x12\x11\n\tdata_type\x18\x04 \x01(\t\"m\n&GetSimpleTuningParamDefinitionResponse\x12\x43\n\x06params\x18\x01 \x03(\x0b\x32\x33.zaber.motion.protobufs.SimpleTuningParamDefinition\"\x95\x01\n\x17TranslatorCreateRequest\x12@\n\ndefinition\x18\x01 \x01(\x0b\x32,.zaber.motion.protobufs.TranslatorDefinition\x12\x38\n\x06\x63onfig\x18\x02 \x01(\x0b\x32(.zaber.motion.protobufs.TranslatorConfig\"1\n\x18TranslatorCreateResponse\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\"O\n\x18TranslatorAxisDefinition\x12\x15\n\rperipheral_id\x18\x01 \x01(\x05\x12\x1c\n\x14microstep_resolution\x18\x02 \x01(\x05\"\xa1\x01\n\x14TranslatorDefinition\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12>\n\x04\x61xes\x18\x02 \x03(\x0b\x32\x30.zaber.motion.protobufs.TranslatorAxisDefinition\x12\x36\n\tmax_speed\x18\x03 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\"\xac\x01\n\x10TranslatorConfig\x12\x44\n\raxis_mappings\x18\x01 \x03(\x0b\x32-.zaber.motion.protobufs.TranslatorAxisMapping\x12R\n\x14\x61xis_transformations\x18\x02 \x03(\x0b\x32\x34.zaber.motion.protobufs.TranslatorAxisTransformation\"@\n\x15TranslatorAxisMapping\x12\x13\n\x0b\x61xis_letter\x18\x01 \x01(\t\x12\x12\n\naxis_index\x18\x02 \x01(\x05\"~\n\x1cTranslatorAxisTransformation\x12\x13\n\x0b\x61xis_letter\x18\x01 \x01(\t\x12\x0f\n\x07scaling\x18\x02 \x01(\x01\x12\x38\n\x0btranslation\x18\x03 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\"B\n\x1aTranslatorTranslateRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\r\n\x05\x62lock\x18\x02 \x01(\t\"I\n\x10TranslateMessage\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x12\n\nfrom_block\x18\x02 \x01(\x05\x12\x10\n\x08to_block\x18\x03 \x01(\x05\"k\n\x1bTranslatorTranslateResponse\x12\x10\n\x08\x63ommands\x18\x01 \x03(\t\x12:\n\x08warnings\x18\x02 \x03(\x0b\x32(.zaber.motion.protobufs.TranslateMessage\"@\n\x18GCodeSyntaxExceptionData\x12\x12\n\nfrom_block\x18\x01 \x01(\x05\x12\x10\n\x08to_block\x18\x02 \x01(\x05\"C\n\x1bGCodeExecutionExceptionData\x12\x12\n\nfrom_block\x18\x01 \x01(\x05\x12\x10\n\x08to_block\x18\x02 \x01(\x05\"L\n\x1aTranslatorFlushLiveRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x02 \x01(\x08\"+\n\x17TranslatorFlushResponse\x12\x10\n\x08\x63ommands\x18\x01 \x03(\t\"\x90\x01\n\x1bTranslatorCreateLiveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x38\n\x06\x63onfig\x18\x04 \x01(\x0b\x32(.zaber.motion.protobufs.TranslatorConfig\"\x91\x01\n!TranslatorCreateFromDeviceRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xes\x18\x03 \x03(\x05\x12\x38\n\x06\x63onfig\x18\x04 \x01(\x0b\x32(.zaber.motion.protobufs.TranslatorConfig\"/\n\x16TranslatorEmptyRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\"^\n TranslatorSetTraverseRateRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x15\n\rtraverse_rate\x18\x02 \x01(\x01\x12\x0c\n\x04unit\x18\x03 \x01(\t\"g\n TranslatorSetAxisPositionRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x02 \x01(\t\x12\x10\n\x08position\x18\x03 \x01(\x01\x12\x0c\n\x04unit\x18\x04 \x01(\t\"U\n TranslatorGetAxisPositionRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x02 \x01(\t\x12\x0c\n\x04unit\x18\x03 \x01(\t\"n\n\x1eTranslatorGetAxisOffsetRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x19\n\x11\x63oordinate_system\x18\x02 \x01(\t\x12\x0c\n\x04\x61xis\x18\x03 \x01(\t\x12\x0c\n\x04unit\x18\x04 \x01(\t\"R\n$TranslatorSetFeedRateOverrideRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x13\n\x0b\x63oefficient\x18\x02 \x01(\x01\"y\n\x17\x44\x65viceSetStorageRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\x12\x0e\n\x06\x65ncode\x18\x06 \x01(\x08\"j\n\x17\x44\x65viceGetStorageRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x0e\n\x06\x64\x65\x63ode\x18\x05 \x01(\x08\"o\n\x1d\x44\x65viceSetStorageNumberRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\x01\"m\n\x1b\x44\x65viceSetStorageBoolRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\x08\"W\n\x14\x44\x65viceStorageRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0b\n\x03key\x18\x04 \x01(\t\"b\n\x1c\x44\x65viceStorageListKeysRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0e\n\x06prefix\x18\x04 \x01(\t\"\xa1\x01\n\x1f\x44\x65viceSetUnitConversionsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0b\n\x03key\x18\x04 \x01(\t\x12=\n\x0b\x63onversions\x18\x05 \x03(\x0b\x32(.zaber.motion.protobufs.ConversionFactor\"@\n\x10\x43onversionFactor\x12\x0f\n\x07setting\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0c\n\x04unit\x18\x03 \x01(\t\"^\n\x17ObjectiveChangerRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0eturret_address\x18\x02 \x01(\x05\x12\x15\n\rfocus_address\x18\x03 \x01(\x05\"?\n\x1eObjectiveChangerCreateResponse\x12\x0e\n\x06turret\x18\x02 \x01(\x05\x12\r\n\x05\x66ocus\x18\x03 \x01(\x05\"\xb2\x01\n\x1dObjectiveChangerChangeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0eturret_address\x18\x02 \x01(\x05\x12\x15\n\rfocus_address\x18\x03 \x01(\x05\x12\x11\n\tobjective\x18\x04 \x01(\x05\x12\x39\n\x0c\x66ocus_offset\x18\x05 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement*-\n\x0bMessageType\x12\t\n\x05REPLY\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\t\n\x05\x41LERT\x10\x02*\xc0\t\n\x06\x45rrors\x12\x13\n\x0fREQUEST_TIMEOUT\x10\x00\x12\x15\n\x11\x43ONNECTION_CLOSED\x10\x01\x12\x14\n\x10INVALID_ARGUMENT\x10\x02\x12\x16\n\x12OUT_OF_REQUEST_IDS\x10\x03\x12\x12\n\x0eINVALID_PACKET\x10\x04\x12\x15\n\x11\x43ONNECTION_FAILED\x10\x05\x12\x13\n\x0fUNKNOWN_REQUEST\x10\x06\x12\x12\n\x0e\x43OMMAND_FAILED\x10\x07\x12\x14\n\x10\x44\x45VICE_DB_FAILED\x10\x08\x12\x10\n\x0cINVALID_DATA\x10\t\x12\x19\n\x15\x44\x45VICE_NOT_IDENTIFIED\x10\n\x12\x15\n\x11\x43ONVERSION_FAILED\x10\x0b\x12\x1b\n\x17\x44\x45VICE_ADDRESS_CONFLICT\x10\x0c\x12\x13\n\x0fNO_DEVICE_FOUND\x10\r\x12\x18\n\x14MOVEMENT_INTERRUPTED\x10\x0e\x12\x13\n\x0fMOVEMENT_FAILED\x10\x0f\x12\r\n\tIO_FAILED\x10\x10\x12\x14\n\x10INVALID_RESPONSE\x10\x11\x12\x11\n\rNOT_SUPPORTED\x10\x12\x12\x11\n\rDEVICE_FAILED\x10\x13\x12\r\n\tOS_FAILED\x10\x14\x12\x12\n\x0eINTERNAL_ERROR\x10\x16\x12\x19\n\x15\x42INARY_COMMAND_FAILED\x10\x18\x12\x15\n\x11\x43OMMAND_PREEMPTED\x10\x19\x12\x18\n\x14LOCKSTEP_NOT_ENABLED\x10\x1a\x12\x14\n\x10LOCKSTEP_ENABLED\x10\x1b\x12\x1b\n\x17IO_CHANNEL_OUT_OF_RANGE\x10\x1c\x12\x15\n\x11SETTING_NOT_FOUND\x10\x1d\x12\x0f\n\x0bSTREAM_MODE\x10\x1e\x12\x14\n\x10STREAM_EXECUTION\x10\x1f\x12\x1a\n\x16STREAM_MOVEMENT_FAILED\x10 \x12\x17\n\x13STREAM_SETUP_FAILED\x10!\x12\x0f\n\x0b\x44\x45VICE_BUSY\x10\"\x12\x1f\n\x1bSTREAM_MOVEMENT_INTERRUPTED\x10#\x12\x16\n\x12INVALID_PARK_STATE\x10$\x12\x14\n\x10SERIAL_PORT_BUSY\x10%\x12\x1a\n\x16TRANSPORT_ALREADY_USED\x10&\x12\x1f\n\x1bSET_PERIPHERAL_STATE_FAILED\x10\'\x12\x1b\n\x17SET_DEVICE_STATE_FAILED\x10(\x12\x11\n\rG_CODE_SYNTAX\x10)\x12\x14\n\x10G_CODE_EXECUTION\x10*\x12\x15\n\x11INVALID_OPERATION\x10+\x12\x14\n\x10\x43OMMAND_TOO_LONG\x10,\x12\x14\n\x10NO_VALUE_FOR_KEY\x10-\x12\x1b\n\x17\x44\x45VICE_DETECTION_FAILED\x10.\x12\x0b\n\x07TIMEOUT\x10/\x12\x0c\n\x08PVT_MODE\x10\x30\x12\x11\n\rPVT_EXECUTION\x10\x31\x12\x14\n\x10PVT_SETUP_FAILED\x10\x32\x12\x17\n\x13PVT_MOVEMENT_FAILED\x10\x33\x12\x1c\n\x18PVT_MOVEMENT_INTERRUPTED\x10\x34\x12\x15\n\x11PVT_DISCONTINUITY\x10\x35\x12\x18\n\x14STREAM_DISCONTINUITY\x10\x36*Q\n\rInterfaceType\x12\x0f\n\x0bSERIAL_PORT\x10\x00\x12\x07\n\x03TCP\x10\x01\x12\n\n\x06\x43USTOM\x10\x02\x12\x07\n\x03IOT\x10\x03\x12\x11\n\rNETWORK_SHARE\x10\x04\x42$Z\"./protobufs;zaber_motion_protobufsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protobufs.main_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\"./protobufs;zaber_motion_protobufs'
  _MESSAGETYPE._serialized_start=22143
  _MESSAGETYPE._serialized_end=22188
  _ERRORS._serialized_start=22191
  _ERRORS._serialized_end=23407
  _INTERFACETYPE._serialized_start=23409
  _INTERFACETYPE._serialized_end=23490
  _REQUEST._serialized_start=48
  _REQUEST._serialized_end=74
  _RESPONSE._serialized_start=77
  _RESPONSE._serialized_end=262
  _RESPONSE_RESPONSETYPE._serialized_start=229
  _RESPONSE_RESPONSETYPE._serialized_end=262
  _EVENT._serialized_start=264
  _EVENT._serialized_end=286
  _EMPTYREQUEST._serialized_start=288
  _EMPTYREQUEST._serialized_end=302
  _BOOLRESPONSE._serialized_start=304
  _BOOLRESPONSE._serialized_end=333
  _DOUBLERESPONSE._serialized_start=335
  _DOUBLERESPONSE._serialized_end=366
  _DOUBLEARRAYRESPONSE._serialized_start=368
  _DOUBLEARRAYRESPONSE._serialized_end=405
  _INTRESPONSE._serialized_start=407
  _INTRESPONSE._serialized_end=435
  _STRINGRESPONSE._serialized_start=437
  _STRINGRESPONSE._serialized_end=468
  _STRINGARRAYRESPONSE._serialized_start=470
  _STRINGARRAYRESPONSE._serialized_end=507
  _AXISIDENTITY._serialized_start=510
  _AXISIDENTITY._serialized_end=731
  _AXISIDENTITY_AXISTYPE._serialized_start=684
  _AXISIDENTITY_AXISTYPE._serialized_end=731
  _DEVICEIDENTITY._serialized_start=734
  _DEVICEIDENTITY._serialized_end=937
  _FIRMWAREVERSION._serialized_start=939
  _FIRMWAREVERSION._serialized_end=1001
  _DEVICEIOINFO._serialized_start=1004
  _DEVICEIOINFO._serialized_end=1142
  _MEASUREMENT._serialized_start=1144
  _MEASUREMENT._serialized_end=1186
  _STREAMAXISDEFINITION._serialized_start=1188
  _STREAMAXISDEFINITION._serialized_end=1250
  _INVALIDPACKETEXCEPTIONDATA._serialized_start=1252
  _INVALIDPACKETEXCEPTIONDATA._serialized_end=1312
  _DEVICEADDRESSCONFLICTEXCEPTIONDATA._serialized_start=1314
  _DEVICEADDRESSCONFLICTEXCEPTIONDATA._serialized_end=1376
  _MOVEMENTINTERRUPTEDEXCEPTIONDATA._serialized_start=1378
  _MOVEMENTINTERRUPTEDEXCEPTIONDATA._serialized_end=1476
  _STREAMMOVEMENTINTERRUPTEDEXCEPTIONDATA._serialized_start=1478
  _STREAMMOVEMENTINTERRUPTEDEXCEPTIONDATA._serialized_end=1552
  _PVTMOVEMENTINTERRUPTEDEXCEPTIONDATA._serialized_start=1554
  _PVTMOVEMENTINTERRUPTEDEXCEPTIONDATA._serialized_end=1625
  _MOVEMENTFAILEDEXCEPTIONDATA._serialized_start=1627
  _MOVEMENTFAILEDEXCEPTIONDATA._serialized_end=1720
  _STREAMMOVEMENTFAILEDEXCEPTIONDATA._serialized_start=1722
  _STREAMMOVEMENTFAILEDEXCEPTIONDATA._serialized_end=1791
  _PVTMOVEMENTFAILEDEXCEPTIONDATA._serialized_start=1793
  _PVTMOVEMENTFAILEDEXCEPTIONDATA._serialized_end=1859
  _STREAMEXECUTIONEXCEPTIONDATA._serialized_start=1861
  _STREAMEXECUTIONEXCEPTIONDATA._serialized_end=1927
  _PVTEXECUTIONEXCEPTIONDATA._serialized_start=1930
  _PVTEXECUTIONEXCEPTIONDATA._serialized_end=2058
  _INVALIDPVTPOINT._serialized_start=2060
  _INVALIDPVTPOINT._serialized_end=2107
  _INVALIDRESPONSEEXCEPTIONDATA._serialized_start=2109
  _INVALIDRESPONSEEXCEPTIONDATA._serialized_end=2157
  _COMMANDFAILEDEXCEPTIONDATA._serialized_start=2160
  _COMMANDFAILEDEXCEPTIONDATA._serialized_end=2343
  _BINARYCOMMANDFAILEDEXCEPTIONDATA._serialized_start=2345
  _BINARYCOMMANDFAILEDEXCEPTIONDATA._serialized_end=2402
  _SETPERIPHERALSTATEEXCEPTIONDATA._serialized_start=2405
  _SETPERIPHERALSTATEEXCEPTIONDATA._serialized_end=2542
  _SETDEVICESTATEEXCEPTIONDATA._serialized_start=2545
  _SETDEVICESTATEEXCEPTIONDATA._serialized_end=2798
  _COMMANDTOOLONGEXCEPTIONDATA._serialized_start=2800
  _COMMANDTOOLONGEXCEPTIONDATA._serialized_end=2903
  _TESTREQUEST._serialized_start=2905
  _TESTREQUEST._serialized_end=2991
  _TESTRESPONSE._serialized_start=2993
  _TESTRESPONSE._serialized_end=3026
  _TESTRESPONSELONG._serialized_start=3028
  _TESTRESPONSELONG._serialized_end=3065
  _TESTEVENT._serialized_start=3067
  _TESTEVENT._serialized_end=3092
  _TOOLSLISTSERIALPORTSRESPONSE._serialized_start=3094
  _TOOLSLISTSERIALPORTSRESPONSE._serialized_end=3139
  _SETINTERNALMODEREQUEST._serialized_start=3141
  _SETINTERNALMODEREQUEST._serialized_end=3179
  _SETDEVICEDBSOURCEREQUEST._serialized_start=3181
  _SETDEVICEDBSOURCEREQUEST._serialized_end=3254
  _TOGGLEDEVICEDBSTOREREQUEST._serialized_start=3256
  _TOGGLEDEVICEDBSTOREREQUEST._serialized_end=3327
  _DEVICEDBFAILEDEXCEPTIONDATA._serialized_start=3329
  _DEVICEDBFAILEDEXCEPTIONDATA._serialized_end=3372
  _OPENINTERFACEREQUEST._serialized_start=3375
  _OPENINTERFACEREQUEST._serialized_end=3670
  _OPENINTERFACERESPONSE._serialized_start=3672
  _OPENINTERFACERESPONSE._serialized_end=3717
  _INTERFACEEMPTYREQUEST._serialized_start=3719
  _INTERFACEEMPTYREQUEST._serialized_end=3764
  _SETINTERFACETIMEOUTREQUEST._serialized_start=3766
  _SETINTERFACETIMEOUTREQUEST._serialized_end=3833
  _SETINTERFACECHECKSUMENABLEDREQUEST._serialized_start=3835
  _SETINTERFACECHECKSUMENABLEDREQUEST._serialized_end=3913
  _AXISEMPTYREQUEST._serialized_start=3915
  _AXISEMPTYREQUEST._serialized_end=3985
  _GENERICCOMMANDREQUEST._serialized_start=3988
  _GENERICCOMMANDREQUEST._serialized_end=4119
  _GENERICCOMMANDRESPONSE._serialized_start=4122
  _GENERICCOMMANDRESPONSE._serialized_end=4322
  _GENERICCOMMANDRESPONSECOLLECTION._serialized_start=4324
  _GENERICCOMMANDRESPONSECOLLECTION._serialized_end=4425
  _UNKNOWNRESPONSEEVENT._serialized_start=4428
  _UNKNOWNRESPONSEEVENT._serialized_end=4648
  _ALERTEVENT._serialized_start=4651
  _ALERTEVENT._serialized_end=4782
  _DISCONNECTEDEVENT._serialized_start=4784
  _DISCONNECTEDEVENT._serialized_end=4900
  _DEVICEIDENTIFYREQUEST._serialized_start=4902
  _DEVICEIDENTIFYREQUEST._serialized_end=5028
  _DEVICERENUMBERREQUEST._serialized_start=5030
  _DEVICERENUMBERREQUEST._serialized_end=5098
  _DEVICEDETECTREQUEST._serialized_start=5100
  _DEVICEDETECTREQUEST._serialized_end=5169
  _DEVICEDETECTRESPONSE._serialized_start=5171
  _DEVICEDETECTRESPONSE._serialized_end=5210
  _DEVICEHOMEREQUEST._serialized_start=5212
  _DEVICEHOMEREQUEST._serialized_end=5308
  _DEVICEWAITUNTILIDLEREQUEST._serialized_start=5310
  _DEVICEWAITUNTILIDLEREQUEST._serialized_end=5420
  _DEVICEMOVEREQUEST._serialized_start=5423
  _DEVICEMOVEREQUEST._serialized_end=5759
  _DEVICEMOVEREQUEST_MOVETYPE._serialized_start=5704
  _DEVICEMOVEREQUEST_MOVETYPE._serialized_end=5759
  _DEVICESTOPREQUEST._serialized_start=5761
  _DEVICESTOPREQUEST._serialized_end=5857
  _DEVICEONALLREQUEST._serialized_start=5859
  _DEVICEONALLREQUEST._serialized_end=5926
  _DEVICEONALLRESPONSE._serialized_start=5928
  _DEVICEONALLRESPONSE._serialized_end=5975
  _DEVICEGETWARNINGSREQUEST._serialized_start=5977
  _DEVICEGETWARNINGSREQUEST._serialized_end=6070
  _DEVICEGETWARNINGSRESPONSE._serialized_start=6072
  _DEVICEGETWARNINGSRESPONSE._serialized_end=6114
  _WAITTOCLEARWARNINGSREQUEST._serialized_start=6116
  _WAITTOCLEARWARNINGSREQUEST._serialized_end=6236
  _DEVICEGETALLDIGITALIOREQUEST._serialized_start=6238
  _DEVICEGETALLDIGITALIOREQUEST._serialized_end=6328
  _DEVICEGETALLDIGITALIORESPONSE._serialized_start=6330
  _DEVICEGETALLDIGITALIORESPONSE._serialized_end=6377
  _DEVICEGETALLANALOGIOREQUEST._serialized_start=6379
  _DEVICEGETALLANALOGIOREQUEST._serialized_end=6468
  _DEVICEGETALLANALOGIORESPONSE._serialized_start=6470
  _DEVICEGETALLANALOGIORESPONSE._serialized_end=6516
  _DEVICEGETDIGITALIOREQUEST._serialized_start=6518
  _DEVICEGETDIGITALIOREQUEST._serialized_end=6629
  _DEVICEGETANALOGIOREQUEST._serialized_start=6631
  _DEVICEGETANALOGIOREQUEST._serialized_end=6741
  _DEVICESETALLDIGITALOUTPUTSREQUEST._serialized_start=6743
  _DEVICESETALLDIGITALOUTPUTSREQUEST._serialized_end=6832
  _DEVICESETALLANALOGOUTPUTSREQUEST._serialized_start=6834
  _DEVICESETALLANALOGOUTPUTSREQUEST._serialized_end=6922
  _DEVICESETDIGITALOUTPUTREQUEST._serialized_start=6924
  _DEVICESETDIGITALOUTPUTREQUEST._serialized_end=7032
  _DEVICESETANALOGOUTPUTREQUEST._serialized_start=7034
  _DEVICESETANALOGOUTPUTREQUEST._serialized_end=7141
  _SETLOGOUTPUTREQUEST._serialized_start=7143
  _SETLOGOUTPUTREQUEST._serialized_end=7197
  _DEVICEGETSETTINGREQUEST._serialized_start=7199
  _DEVICEGETSETTINGREQUEST._serialized_end=7307
  _DEVICECONVERTSETTINGREQUEST._serialized_start=7310
  _DEVICECONVERTSETTINGREQUEST._serialized_end=7458
  _DEVICESETSETTINGREQUEST._serialized_start=7460
  _DEVICESETSETTINGREQUEST._serialized_end=7583
  _DEVICESETSETTINGSTRREQUEST._serialized_start=7585
  _DEVICESETSETTINGSTRREQUEST._serialized_end=7697
  _PREPARECOMMANDREQUEST._serialized_start=7700
  _PREPARECOMMANDREQUEST._serialized_end=7858
  _WAITTORESPONDREQUEST._serialized_start=7860
  _WAITTORESPONDREQUEST._serialized_end=7937
  _LOCKSTEPENABLEREQUEST._serialized_start=7939
  _LOCKSTEPENABLEREQUEST._serialized_end=8041
  _LOCKSTEPDISABLEREQUEST._serialized_start=8043
  _LOCKSTEPDISABLEREQUEST._serialized_end=8157
  _LOCKSTEPSTOPREQUEST._serialized_start=8159
  _LOCKSTEPSTOPREQUEST._serialized_end=8270
  _LOCKSTEPHOMEREQUEST._serialized_start=8272
  _LOCKSTEPHOMEREQUEST._serialized_end=8383
  _LOCKSTEPMOVEREQUEST._serialized_start=8386
  _LOCKSTEPMOVEREQUEST._serialized_end=8739
  _LOCKSTEPMOVEREQUEST_MOVETYPE._serialized_start=5704
  _LOCKSTEPMOVEREQUEST_MOVETYPE._serialized_end=5759
  _LOCKSTEPWAITUNTILIDLEREQUEST._serialized_start=8741
  _LOCKSTEPWAITUNTILIDLEREQUEST._serialized_end=8866
  _LOCKSTEPEMPTYREQUEST._serialized_start=8868
  _LOCKSTEPEMPTYREQUEST._serialized_end=8955
  _LOCKSTEPAXES._serialized_start=8957
  _LOCKSTEPAXES._serialized_end=9035
  _LOCKSTEPGETAXISNUMBERSRESPONSE._serialized_start=9037
  _LOCKSTEPGETAXISNUMBERSRESPONSE._serialized_end=9083
  _LOCKSTEPGETREQUEST._serialized_start=9085
  _LOCKSTEPGETREQUEST._serialized_end=9184
  _LOCKSTEPSETREQUEST._serialized_start=9187
  _LOCKSTEPSETREQUEST._serialized_end=9321
  _OSCILLOSCOPEADDCHANNELREQUEST._serialized_start=9323
  _OSCILLOSCOPEADDCHANNELREQUEST._serialized_end=9423
  _OSCILLOSCOPESTARTSTOPREQUEST._serialized_start=9425
  _OSCILLOSCOPESTARTSTOPREQUEST._serialized_end=9532
  _OSCILLOSCOPEREADRESPONSE._serialized_start=9534
  _OSCILLOSCOPEREADRESPONSE._serialized_end=9578
  _OSCILLOSCOPEDATAIDENTIFIER._serialized_start=9580
  _OSCILLOSCOPEDATAIDENTIFIER._serialized_end=9625
  _OSCILLOSCOPECAPTUREPROPERTIES._serialized_start=9627
  _OSCILLOSCOPECAPTUREPROPERTIES._serialized_end=9696
  _OSCILLOSCOPEDATAGETREQUEST._serialized_start=9698
  _OSCILLOSCOPEDATAGETREQUEST._serialized_end=9757
  _OSCILLOSCOPEDATAGETSAMPLETIMEREQUEST._serialized_start=9759
  _OSCILLOSCOPEDATAGETSAMPLETIMEREQUEST._serialized_end=9843
  _OSCILLOSCOPEDATAGETSAMPLESRESPONSE._serialized_start=9845
  _OSCILLOSCOPEDATAGETSAMPLESRESPONSE._serialized_end=9895
  _STREAMSETUPLIVEREQUEST._serialized_start=9897
  _STREAMSETUPLIVEREQUEST._serialized_end=10005
  _STREAMSETUPLIVECOMPOSITEREQUEST._serialized_start=10008
  _STREAMSETUPLIVECOMPOSITEREQUEST._serialized_end=10171
  _STREAMSETUPSTOREREQUEST._serialized_start=10174
  _STREAMSETUPSTOREREQUEST._serialized_end=10326
  _STREAMSETUPSTORECOMPOSITEREQUEST._serialized_start=10329
  _STREAMSETUPSTORECOMPOSITEREQUEST._serialized_end=10536
  _STREAMSETUPSTOREARBITRARYAXESREQUEST._serialized_start=10539
  _STREAMSETUPSTOREARBITRARYAXESREQUEST._serialized_end=10710
  _STREAMCALLREQUEST._serialized_start=10713
  _STREAMCALLREQUEST._serialized_end=10845
  _PVTPOINTREQUEST._serialized_start=10848
  _PVTPOINTREQUEST._serialized_end=11185
  _PVTPOINTREQUEST_TYPE._serialized_start=11161
  _PVTPOINTREQUEST_TYPE._serialized_end=11185
  _STREAMLINEREQUEST._serialized_start=11188
  _STREAMLINEREQUEST._serialized_end=11449
  _STREAMLINEREQUEST_TYPE._serialized_start=11161
  _STREAMLINEREQUEST_TYPE._serialized_end=11185
  _STREAMARCREQUEST._serialized_start=11452
  _STREAMARCREQUEST._serialized_end=11898
  _STREAMARCREQUEST_TYPE._serialized_start=11161
  _STREAMARCREQUEST_TYPE._serialized_end=11185
  _STREAMCIRCLEREQUEST._serialized_start=11901
  _STREAMCIRCLEREQUEST._serialized_end=12249
  _STREAMCIRCLEREQUEST_TYPE._serialized_start=11161
  _STREAMCIRCLEREQUEST_TYPE._serialized_end=11185
  _STREAMWAITDIGITALINPUTREQUEST._serialized_start=12252
  _STREAMWAITDIGITALINPUTREQUEST._serialized_end=12392
  _STREAMWAITANALOGINPUTREQUEST._serialized_start=12395
  _STREAMWAITANALOGINPUTREQUEST._serialized_end=12553
  _STREAMSETDIGITALOUTPUTREQUEST._serialized_start=12556
  _STREAMSETDIGITALOUTPUTREQUEST._serialized_end=12696
  _STREAMSETANALOGOUTPUTREQUEST._serialized_start=12699
  _STREAMSETANALOGOUTPUTREQUEST._serialized_end=12838
  _STREAMTOGGLEDIGITALOUTPUTREQUEST._serialized_start=12841
  _STREAMTOGGLEDIGITALOUTPUTREQUEST._serialized_end=12969
  _STREAMSETALLDIGITALOUTPUTSREQUEST._serialized_start=12971
  _STREAMSETALLDIGITALOUTPUTSREQUEST._serialized_end=13092
  _STREAMSETALLANALOGOUTPUTSREQUEST._serialized_start=13094
  _STREAMSETALLANALOGOUTPUTSREQUEST._serialized_end=13214
  _STREAMWAITREQUEST._serialized_start=13216
  _STREAMWAITREQUEST._serialized_end=13333
  _STREAMWAITUNTILIDLEREQUEST._serialized_start=13336
  _STREAMWAITUNTILIDLEREQUEST._serialized_end=13464
  _STREAMEMPTYREQUEST._serialized_start=13466
  _STREAMEMPTYREQUEST._serialized_end=13556
  _STREAMGETAXESRESPONSE._serialized_start=13558
  _STREAMGETAXESRESPONSE._serialized_end=13641
  _STREAMGETMAXSPEEDREQUEST._serialized_start=13643
  _STREAMGETMAXSPEEDREQUEST._serialized_end=13753
  _STREAMSETMAXSPEEDREQUEST._serialized_start=13756
  _STREAMSETMAXSPEEDREQUEST._serialized_end=13885
  _STREAMGETMAXTANGENTIALACCELERATIONREQUEST._serialized_start=13887
  _STREAMGETMAXTANGENTIALACCELERATIONREQUEST._serialized_end=14014
  _STREAMSETMAXTANGENTIALACCELERATIONREQUEST._serialized_start=14017
  _STREAMSETMAXTANGENTIALACCELERATIONREQUEST._serialized_end=14181
  _STREAMGETMAXCENTRIPETALACCELERATIONREQUEST._serialized_start=14184
  _STREAMGETMAXCENTRIPETALACCELERATIONREQUEST._serialized_end=14312
  _STREAMSETMAXCENTRIPETALACCELERATIONREQUEST._serialized_start=14315
  _STREAMSETMAXCENTRIPETALACCELERATIONREQUEST._serialized_end=14481
  _STREAMBUFFERGETCONTENTREQUEST._serialized_start=14483
  _STREAMBUFFERGETCONTENTREQUEST._serialized_end=14584
  _STREAMBUFFERGETCONTENTRESPONSE._serialized_start=14586
  _STREAMBUFFERGETCONTENTRESPONSE._serialized_end=14640
  _STREAMBUFFERERASEREQUEST._serialized_start=14642
  _STREAMBUFFERERASEREQUEST._serialized_end=14738
  _STREAMGENERICCOMMANDREQUEST._serialized_start=14740
  _STREAMGENERICCOMMANDREQUEST._serialized_end=14856
  _STREAMGENERICCOMMANDBATCHREQUEST._serialized_start=14858
  _STREAMGENERICCOMMANDBATCHREQUEST._serialized_end=14977
  _BINARYREPLYONLYEVENT._serialized_start=14979
  _BINARYREPLYONLYEVENT._serialized_end=15078
  _OPENBINARYINTERFACEREQUEST._serialized_start=15081
  _OPENBINARYINTERFACEREQUEST._serialized_end=15268
  _UNKNOWNBINARYRESPONSEEVENT._serialized_start=15270
  _UNKNOWNBINARYRESPONSEEVENT._serialized_end=15375
  _GENERICBINARYREQUEST._serialized_start=15378
  _GENERICBINARYREQUEST._serialized_end=15508
  _BINARYMESSAGE._serialized_start=15510
  _BINARYMESSAGE._serialized_end=15580
  _BINARYMESSAGECOLLECTION._serialized_start=15582
  _BINARYMESSAGECOLLECTION._serialized_end=15664
  _DEVICEEMPTYREQUEST._serialized_start=15666
  _DEVICEEMPTYREQUEST._serialized_end=15724
  _BINARYDEVICEIDENTITY._serialized_start=15727
  _BINARYDEVICEIDENTITY._serialized_end=16072
  _BINARYDEVICEIDENTITY_DEVICETYPE._serialized_start=16023
  _BINARYDEVICEIDENTITY_DEVICETYPE._serialized_end=16072
  _BINARYGENERICWITHUNITSREQUEST._serialized_start=16075
  _BINARYGENERICWITHUNITSREQUEST._serialized_end=16228
  _BINARYDEVICEHOMEREQUEST._serialized_start=16230
  _BINARYDEVICEHOMEREQUEST._serialized_end=16324
  _BINARYDEVICEMOVEREQUEST._serialized_start=16327
  _BINARYDEVICEMOVEREQUEST._serialized_end=16545
  _BINARYDEVICEMOVEREQUEST_MOVETYPE._serialized_start=5704
  _BINARYDEVICEMOVEREQUEST_MOVETYPE._serialized_end=5741
  _BINARYDEVICESTOPREQUEST._serialized_start=16547
  _BINARYDEVICESTOPREQUEST._serialized_end=16641
  _BINARYDEVICEDETECTREQUEST._serialized_start=16643
  _BINARYDEVICEDETECTREQUEST._serialized_end=16718
  _BINARYDEVICEDETECTRESPONSE._serialized_start=16720
  _BINARYDEVICEDETECTRESPONSE._serialized_end=16765
  _BINARYDEVICEGETSETTINGREQUEST._serialized_start=16767
  _BINARYDEVICEGETSETTINGREQUEST._serialized_end=16867
  _BINARYDEVICESETSETTINGREQUEST._serialized_start=16869
  _BINARYDEVICESETSETTINGREQUEST._serialized_end=16984
  _CUSTOMINTERFACEREADREQUEST._serialized_start=16986
  _CUSTOMINTERFACEREADREQUEST._serialized_end=17036
  _CUSTOMINTERFACEWRITEREQUEST._serialized_start=17038
  _CUSTOMINTERFACEWRITEREQUEST._serialized_end=17106
  _CUSTOMINTERFACEOPENRESPONSE._serialized_start=17108
  _CUSTOMINTERFACEOPENRESPONSE._serialized_end=17159
  _CUSTOMINTERFACECLOSEREQUEST._serialized_start=17161
  _CUSTOMINTERFACECLOSEREQUEST._serialized_end=17235
  _CANSETSTATEREQUEST._serialized_start=17237
  _CANSETSTATEREQUEST._serialized_end=17324
  _CANSETSTATEAXISRESPONSE._serialized_start=17326
  _CANSETSTATEAXISRESPONSE._serialized_end=17387
  _CANSETSTATEDEVICERESPONSE._serialized_start=17389
  _CANSETSTATEDEVICERESPONSE._serialized_end=17501
  _SETSTATEREQUEST._serialized_start=17503
  _SETSTATEREQUEST._serialized_end=17608
  _SERVOTUNINGREQUEST._serialized_start=17610
  _SERVOTUNINGREQUEST._serialized_end=17700
  _SERVOTUNINGPARAM._serialized_start=17702
  _SERVOTUNINGPARAM._serialized_end=17749
  _PARAMSETINFO._serialized_start=17751
  _PARAMSETINFO._serialized_end=17854
  _SETSERVOTUNINGREQUEST._serialized_start=17857
  _SETSERVOTUNINGREQUEST._serialized_end=18015
  _LOADPARAMSET._serialized_start=18017
  _LOADPARAMSET._serialized_end=18127
  _SETSERVOTUNINGPIDREQUEST._serialized_start=18130
  _SETSERVOTUNINGPIDREQUEST._serialized_end=18271
  _PIDTUNING._serialized_start=18273
  _PIDTUNING._serialized_end=18360
  _SETSIMPLETUNING._serialized_start=18363
  _SETSIMPLETUNING._serialized_end=18557
  _SIMPLETUNINGPARAMDEFINITION._serialized_start=18559
  _SIMPLETUNINGPARAMDEFINITION._serialized_end=18659
  _GETSIMPLETUNINGPARAMDEFINITIONRESPONSE._serialized_start=18661
  _GETSIMPLETUNINGPARAMDEFINITIONRESPONSE._serialized_end=18770
  _TRANSLATORCREATEREQUEST._serialized_start=18773
  _TRANSLATORCREATEREQUEST._serialized_end=18922
  _TRANSLATORCREATERESPONSE._serialized_start=18924
  _TRANSLATORCREATERESPONSE._serialized_end=18973
  _TRANSLATORAXISDEFINITION._serialized_start=18975
  _TRANSLATORAXISDEFINITION._serialized_end=19054
  _TRANSLATORDEFINITION._serialized_start=19057
  _TRANSLATORDEFINITION._serialized_end=19218
  _TRANSLATORCONFIG._serialized_start=19221
  _TRANSLATORCONFIG._serialized_end=19393
  _TRANSLATORAXISMAPPING._serialized_start=19395
  _TRANSLATORAXISMAPPING._serialized_end=19459
  _TRANSLATORAXISTRANSFORMATION._serialized_start=19461
  _TRANSLATORAXISTRANSFORMATION._serialized_end=19587
  _TRANSLATORTRANSLATEREQUEST._serialized_start=19589
  _TRANSLATORTRANSLATEREQUEST._serialized_end=19655
  _TRANSLATEMESSAGE._serialized_start=19657
  _TRANSLATEMESSAGE._serialized_end=19730
  _TRANSLATORTRANSLATERESPONSE._serialized_start=19732
  _TRANSLATORTRANSLATERESPONSE._serialized_end=19839
  _GCODESYNTAXEXCEPTIONDATA._serialized_start=19841
  _GCODESYNTAXEXCEPTIONDATA._serialized_end=19905
  _GCODEEXECUTIONEXCEPTIONDATA._serialized_start=19907
  _GCODEEXECUTIONEXCEPTIONDATA._serialized_end=19974
  _TRANSLATORFLUSHLIVEREQUEST._serialized_start=19976
  _TRANSLATORFLUSHLIVEREQUEST._serialized_end=20052
  _TRANSLATORFLUSHRESPONSE._serialized_start=20054
  _TRANSLATORFLUSHRESPONSE._serialized_end=20097
  _TRANSLATORCREATELIVEREQUEST._serialized_start=20100
  _TRANSLATORCREATELIVEREQUEST._serialized_end=20244
  _TRANSLATORCREATEFROMDEVICEREQUEST._serialized_start=20247
  _TRANSLATORCREATEFROMDEVICEREQUEST._serialized_end=20392
  _TRANSLATOREMPTYREQUEST._serialized_start=20394
  _TRANSLATOREMPTYREQUEST._serialized_end=20441
  _TRANSLATORSETTRAVERSERATEREQUEST._serialized_start=20443
  _TRANSLATORSETTRAVERSERATEREQUEST._serialized_end=20537
  _TRANSLATORSETAXISPOSITIONREQUEST._serialized_start=20539
  _TRANSLATORSETAXISPOSITIONREQUEST._serialized_end=20642
  _TRANSLATORGETAXISPOSITIONREQUEST._serialized_start=20644
  _TRANSLATORGETAXISPOSITIONREQUEST._serialized_end=20729
  _TRANSLATORGETAXISOFFSETREQUEST._serialized_start=20731
  _TRANSLATORGETAXISOFFSETREQUEST._serialized_end=20841
  _TRANSLATORSETFEEDRATEOVERRIDEREQUEST._serialized_start=20843
  _TRANSLATORSETFEEDRATEOVERRIDEREQUEST._serialized_end=20925
  _DEVICESETSTORAGEREQUEST._serialized_start=20927
  _DEVICESETSTORAGEREQUEST._serialized_end=21048
  _DEVICEGETSTORAGEREQUEST._serialized_start=21050
  _DEVICEGETSTORAGEREQUEST._serialized_end=21156
  _DEVICESETSTORAGENUMBERREQUEST._serialized_start=21158
  _DEVICESETSTORAGENUMBERREQUEST._serialized_end=21269
  _DEVICESETSTORAGEBOOLREQUEST._serialized_start=21271
  _DEVICESETSTORAGEBOOLREQUEST._serialized_end=21380
  _DEVICESTORAGEREQUEST._serialized_start=21382
  _DEVICESTORAGEREQUEST._serialized_end=21469
  _DEVICESTORAGELISTKEYSREQUEST._serialized_start=21471
  _DEVICESTORAGELISTKEYSREQUEST._serialized_end=21569
  _DEVICESETUNITCONVERSIONSREQUEST._serialized_start=21572
  _DEVICESETUNITCONVERSIONSREQUEST._serialized_end=21733
  _CONVERSIONFACTOR._serialized_start=21735
  _CONVERSIONFACTOR._serialized_end=21799
  _OBJECTIVECHANGERREQUEST._serialized_start=21801
  _OBJECTIVECHANGERREQUEST._serialized_end=21895
  _OBJECTIVECHANGERCREATERESPONSE._serialized_start=21897
  _OBJECTIVECHANGERCREATERESPONSE._serialized_end=21960
  _OBJECTIVECHANGERCHANGEREQUEST._serialized_start=21963
  _OBJECTIVECHANGERCHANGEREQUEST._serialized_end=22141
# @@protoc_insertion_point(module_scope)



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #

from .protobufs import main_pb2 as protobufs
from .units import UnitsAndLiterals as UnitsAndLiterals, Units as Units
from .library import Library as Library
from .log_output_mode import LogOutputMode as LogOutputMode
from .tools import Tools as Tools
from .device_db_source_type import DeviceDbSourceType as DeviceDbSourceType
from .measurement import Measurement as Measurement
from .convert_exception import convert_exception as convert_exception
from .firmware_version import FirmwareVersion as FirmwareVersion
from .rotation_direction import RotationDirection as RotationDirection
from .version import __version__ as __version__

from .exceptions import MotionLibException as MotionLibException
from .exceptions import BinaryCommandFailedException as BinaryCommandFailedException
from .exceptions import CommandFailedException as CommandFailedException
from .exceptions import CommandPreemptedException as CommandPreemptedException
from .exceptions import CommandTooLongException as CommandTooLongException
from .exceptions import ConnectionClosedException as ConnectionClosedException
from .exceptions import ConnectionFailedException as ConnectionFailedException
from .exceptions import ConversionFailedException as ConversionFailedException
from .exceptions import DeviceAddressConflictException as DeviceAddressConflictException
from .exceptions import DeviceBusyException as DeviceBusyException
from .exceptions import DeviceDbFailedException as DeviceDbFailedException
from .exceptions import DeviceDetectionFailedException as DeviceDetectionFailedException
from .exceptions import DeviceFailedException as DeviceFailedException
from .exceptions import DeviceNotIdentifiedException as DeviceNotIdentifiedException
from .exceptions import GCodeExecutionException as GCodeExecutionException
from .exceptions import GCodeSyntaxException as GCodeSyntaxException
from .exceptions import InternalErrorException as InternalErrorException
from .exceptions import InvalidArgumentException as InvalidArgumentException
from .exceptions import InvalidDataException as InvalidDataException
from .exceptions import InvalidOperationException as InvalidOperationException
from .exceptions import InvalidPacketException as InvalidPacketException
from .exceptions import InvalidParkStateException as InvalidParkStateException
from .exceptions import InvalidResponseException as InvalidResponseException
from .exceptions import IoChannelOutOfRangeException as IoChannelOutOfRangeException
from .exceptions import IoFailedException as IoFailedException
from .exceptions import LockstepEnabledException as LockstepEnabledException
from .exceptions import LockstepNotEnabledException as LockstepNotEnabledException
from .exceptions import MovementFailedException as MovementFailedException
from .exceptions import MovementInterruptedException as MovementInterruptedException
from .exceptions import NoDeviceFoundException as NoDeviceFoundException
from .exceptions import NoValueForKeyException as NoValueForKeyException
from .exceptions import NotSupportedException as NotSupportedException
from .exceptions import OsFailedException as OsFailedException
from .exceptions import OutOfRequestIdsException as OutOfRequestIdsException
from .exceptions import PvtDiscontinuityException as PvtDiscontinuityException
from .exceptions import PvtExecutionException as PvtExecutionException
from .exceptions import PvtModeException as PvtModeException
from .exceptions import PvtMovementFailedException as PvtMovementFailedException
from .exceptions import PvtMovementInterruptedException as PvtMovementInterruptedException
from .exceptions import PvtSetupFailedException as PvtSetupFailedException
from .exceptions import RequestTimeoutException as RequestTimeoutException
from .exceptions import SerialPortBusyException as SerialPortBusyException
from .exceptions import SetDeviceStateFailedException as SetDeviceStateFailedException
from .exceptions import SetPeripheralStateFailedException as SetPeripheralStateFailedException
from .exceptions import SettingNotFoundException as SettingNotFoundException
from .exceptions import StreamDiscontinuityException as StreamDiscontinuityException
from .exceptions import StreamExecutionException as StreamExecutionException
from .exceptions import StreamModeException as StreamModeException
from .exceptions import StreamMovementFailedException as StreamMovementFailedException
from .exceptions import StreamMovementInterruptedException as StreamMovementInterruptedException
from .exceptions import StreamSetupFailedException as StreamSetupFailedException
from .exceptions import TimeoutException as TimeoutException
from .exceptions import TransportAlreadyUsedException as TransportAlreadyUsedException
from .exceptions import UnknownRequestException as UnknownRequestException
from .exceptions import BinaryCommandFailedExceptionData as BinaryCommandFailedExceptionData
from .exceptions import CommandFailedExceptionData as CommandFailedExceptionData
from .exceptions import CommandTooLongExceptionData as CommandTooLongExceptionData
from .exceptions import DeviceAddressConflictExceptionData as DeviceAddressConflictExceptionData
from .exceptions import DeviceDbFailedExceptionData as DeviceDbFailedExceptionData
from .exceptions import GCodeExecutionExceptionData as GCodeExecutionExceptionData
from .exceptions import GCodeSyntaxExceptionData as GCodeSyntaxExceptionData
from .exceptions import InvalidPacketExceptionData as InvalidPacketExceptionData
from .exceptions import InvalidResponseExceptionData as InvalidResponseExceptionData
from .exceptions import MovementFailedExceptionData as MovementFailedExceptionData
from .exceptions import MovementInterruptedExceptionData as MovementInterruptedExceptionData
from .exceptions import PvtExecutionExceptionData as PvtExecutionExceptionData
from .exceptions import PvtMovementFailedExceptionData as PvtMovementFailedExceptionData
from .exceptions import PvtMovementInterruptedExceptionData as PvtMovementInterruptedExceptionData
from .exceptions import SetDeviceStateExceptionData as SetDeviceStateExceptionData
from .exceptions import SetPeripheralStateExceptionData as SetPeripheralStateExceptionData
from .exceptions import StreamExecutionExceptionData as StreamExecutionExceptionData
from .exceptions import StreamMovementFailedExceptionData as StreamMovementFailedExceptionData
from .exceptions import StreamMovementInterruptedExceptionData as StreamMovementInterruptedExceptionData



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
# pylint: disable=W0201

from ..protobufs import main_pb2


class DeviceDbFailedExceptionData:
    """
    Contains additional data for a DeviceDbFailedException.
    """

    @property
    def code(self) -> str:
        """
        Code describing type of the error.
        """

        return self._code

    @code.setter
    def code(self, value: str) -> None:
        self._code = value

    def __repr__(self) -> str:
        return str(self.__dict__)

    @staticmethod
    def from_protobuf(
        pb_data: main_pb2.DeviceDbFailedExceptionData
    ) -> 'DeviceDbFailedExceptionData':
        instance = DeviceDbFailedExceptionData.__new__(
            DeviceDbFailedExceptionData
        )  # type: DeviceDbFailedExceptionData
        instance.code = pb_data.code
        return instance



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
# pylint: disable=W0201

from typing import List  # pylint: disable=unused-import
from ..protobufs import main_pb2
from .set_peripheral_state_exception_data import SetPeripheralStateExceptionData


class SetDeviceStateExceptionData:
    """
    Contains additional data for a SetDeviceStateFailedException.
    """

    @property
    def settings(self) -> List[str]:
        """
        A list of settings which could not be set.
        """

        return self._settings

    @settings.setter
    def settings(self, value: List[str]) -> None:
        self._settings = value

    @property
    def stream_buffers(self) -> List[str]:
        """
        The reason the stream buffers could not be set.
        """

        return self._stream_buffers

    @stream_buffers.setter
    def stream_buffers(self, value: List[str]) -> None:
        self._stream_buffers = value

    @property
    def pvt_buffers(self) -> List[str]:
        """
        The reason the pvt buffers could not be set.
        """

        return self._pvt_buffers

    @pvt_buffers.setter
    def pvt_buffers(self, value: List[str]) -> None:
        self._pvt_buffers = value

    @property
    def triggers(self) -> List[str]:
        """
        The reason the triggers could not be set.
        """

        return self._triggers

    @triggers.setter
    def triggers(self, value: List[str]) -> None:
        self._triggers = value

    @property
    def servo_tuning(self) -> str:
        """
        The reason servo tuning could not be set.
        """

        return self._servo_tuning

    @servo_tuning.setter
    def servo_tuning(self, value: str) -> None:
        self._servo_tuning = value

    @property
    def stored_positions(self) -> List[str]:
        """
        The reasons stored positions could not be set.
        """

        return self._stored_positions

    @stored_positions.setter
    def stored_positions(self, value: List[str]) -> None:
        self._stored_positions = value

    @property
    def storage(self) -> List[str]:
        """
        The reasons storage could not be set.
        """

        return self._storage

    @storage.setter
    def storage(self, value: List[str]) -> None:
        self._storage = value

    @property
    def peripherals(self) -> List[SetPeripheralStateExceptionData]:
        """
        Errors for any peripherals that could not be set.
        """

        return self._peripherals

    @peripherals.setter
    def peripherals(self, value: List[SetPeripheralStateExceptionData]) -> None:
        self._peripherals = value

    def __repr__(self) -> str:
        return str(self.__dict__)

    @staticmethod
    def from_protobuf(
        pb_data: main_pb2.SetDeviceStateExceptionData
    ) -> 'SetDeviceStateExceptionData':
        instance = SetDeviceStateExceptionData.__new__(
            SetDeviceStateExceptionData
        )  # type: SetDeviceStateExceptionData
        instance.settings = list(pb_data.settings)
        instance.stream_buffers = list(pb_data.stream_buffers)
        instance.pvt_buffers = list(pb_data.pvt_buffers)
        instance.triggers = list(pb_data.triggers)
        instance.servo_tuning = pb_data.servo_tuning
        instance.stored_positions = list(pb_data.stored_positions)
        instance.storage = list(pb_data.storage)
        instance.peripherals = [SetPeripheralStateExceptionData.from_protobuf(item) for item in pb_data.peripherals]
        return instance



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
from enum import Enum


class PvtMode(Enum):
    """
    Mode of a PVT sequence.
    """

    DISABLED = 0
    STORE = 1
    LIVE = 2



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
# pylint: disable=W0201

from ..protobufs import main_pb2


class InvalidPvtPoint:
    """
    Contains invalid PVT points for PvtExecutionException.
    """

    @property
    def index(self) -> int:
        """
        Index of the point numbered from the last submitted point.
        """

        return self._index

    @index.setter
    def index(self, value: int) -> None:
        self._index = value

    @property
    def point(self) -> str:
        """
        The textual representation of the point.
        """

        return self._point

    @point.setter
    def point(self, value: str) -> None:
        self._point = value

    def __repr__(self) -> str:
        return str(self.__dict__)

    @staticmethod
    def from_protobuf(
        pb_data: main_pb2.InvalidPvtPoint
    ) -> 'InvalidPvtPoint':
        instance = InvalidPvtPoint.__new__(
            InvalidPvtPoint
        )  # type: InvalidPvtPoint
        instance.index = pb_data.index
        instance.point = pb_data.point
        return instance



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
# pylint: disable=W0201

from ..protobufs import main_pb2


class CommandFailedExceptionData:
    """
    Contains additional data for CommandFailedException.
    """

    @property
    def command(self) -> str:
        """
        The command that got rejected.
        """

        return self._command

    @command.setter
    def command(self, value: str) -> None:
        self._command = value

    @property
    def response_data(self) -> str:
        """
        The data from the reply containing the rejection reason.
        """

        return self._response_data

    @response_data.setter
    def response_data(self, value: str) -> None:
        self._response_data = value

    @property
    def reply_flag(self) -> str:
        """
        The flag indicating that the command was rejected.
        """

        return self._reply_flag

    @reply_flag.setter
    def reply_flag(self, value: str) -> None:
        self._reply_flag = value

    @property
    def status(self) -> str:
        """
        The current device or axis status.
        """

        return self._status

    @status.setter
    def status(self, value: str) -> None:
        self._status = value

    @property
    def warning_flag(self) -> str:
        """
        The highest priority warning flag on the device or axis.
        """

        return self._warning_flag

    @warning_flag.setter
    def warning_flag(self, value: str) -> None:
        self._warning_flag = value

    @property
    def device_address(self) -> int:
        """
        The address of the device that rejected the command.
        """

        return self._device_address

    @device_address.setter
    def device_address(self, value: int) -> None:
        self._device_address = value

    @property
    def axis_number(self) -> int:
        """
        The number of the axis which the rejection relates to.
        """

        return self._axis_number

    @axis_number.setter
    def axis_number(self, value: int) -> None:
        self._axis_number = value

    @property
    def id(self) -> int:
        """
        The message ID of the reply.
        """

        return self._id

    @id.setter
    def id(self, value: int) -> None:
        self._id = value

    def __repr__(self) -> str:
        return str(self.__dict__)

    @staticmethod
    def from_protobuf(
        pb_data: main_pb2.CommandFailedExceptionData
    ) -> 'CommandFailedExceptionData':
        instance = CommandFailedExceptionData.__new__(
            CommandFailedExceptionData
        )  # type: CommandFailedExceptionData
        instance.command = pb_data.command
        instance.response_data = pb_data.response_data
        instance.reply_flag = pb_data.reply_flag
        instance.status = pb_data.status
        instance.warning_flag = pb_data.warning_flag
        instance.device_address = pb_data.device_address
        instance.axis_number = pb_data.axis_number
        instance.id = pb_data.id
        return instance
